#pragma once

#include <limits>
#include <cppcore/misc/flags.h>
#include <cppmariadb/config.h>

namespace cppmariadb
{

    enum class column_type
    {
        Decimal      = MYSQL_TYPE_DECIMAL,
        Tiny         = MYSQL_TYPE_TINY,
        Short        = MYSQL_TYPE_SHORT,
        Long         = MYSQL_TYPE_LONG,
        Float        = MYSQL_TYPE_FLOAT,
        Double       = MYSQL_TYPE_DOUBLE,
        Null         = MYSQL_TYPE_NULL,
        Timestamp    = MYSQL_TYPE_TIMESTAMP,
        Longlong     = MYSQL_TYPE_LONGLONG,
        Int24        = MYSQL_TYPE_INT24,
        Date         = MYSQL_TYPE_DATE,
        Time         = MYSQL_TYPE_TIME,
        DateTime     = MYSQL_TYPE_DATETIME,
        Year         = MYSQL_TYPE_YEAR,
        NewDate      = MYSQL_TYPE_NEWDATE,
        VarChar      = MYSQL_TYPE_VARCHAR,
        Bit          = MYSQL_TYPE_BIT,
        Timestamp2   = MYSQL_TYPE_TIMESTAMP2,
        DateTime2    = MYSQL_TYPE_DATETIME2,
        Time2        = MYSQL_TYPE_TIME2,
        Json         = MYSQL_TYPE_JSON,
        NewDecimal   = MYSQL_TYPE_NEWDECIMAL,
        Enum         = MYSQL_TYPE_ENUM,
        Set          = MYSQL_TYPE_SET,
        TinyBlob     = MYSQL_TYPE_TINY_BLOB,
        MediumBlob   = MYSQL_TYPE_MEDIUM_BLOB,
        LongBlob     = MYSQL_TYPE_LONG_BLOB,
        Blob         = MYSQL_TYPE_BLOB,
        VarString    = MYSQL_TYPE_VAR_STRING,
        String       = MYSQL_TYPE_STRING,
        Geometry     = MYSQL_TYPE_GEOMETRY,
    };

    enum class column_flag : uint
    {
        NotNull         = NOT_NULL_FLAG,            /* field can't be NULL */
        PriKey          = PRI_KEY_FLAG,             /* field is part of a primary key */
        UniqueKey       = UNIQUE_KEY_FLAG,          /* field is part of a unique key */
        MultipleKey     = MULTIPLE_KEY_FLAG,        /* field is part of a key */
        Blob            = BLOB_FLAG,                /* field is a blob */
        Unsigned        = UNSIGNED_FLAG,            /* field is unsigned */
        Zerofill        = ZEROFILL_FLAG,            /* field is zerofill */
        Binary          = BINARY_FLAG,
        Enum            = ENUM_FLAG,                /* field is an enum */
        AutoIncrement   = AUTO_INCREMENT_FLAG,      /* field is a autoincrement field */
        Timestamp       = TIMESTAMP_FLAG,           /* field is a timestamp */
        Set             = SET_FLAG,                 /* field is a set */
        NoDefaultValue  = NO_DEFAULT_VALUE_FLAG,    /* field doesn't have default value */
        OnUpdateNow     = ON_UPDATE_NOW_FLAG,       /* field is set to NOW on UPDATE */
        Num             = NUM_FLAG,                 /* field is num (for clients) */
        PartKey         = PART_KEY_FLAG,            /* Intern; Part of some key */
        Group           = GROUP_FLAG,               /* Intern: Group field */
        Unique          = UNIQUE_FLAG,              /* Intern: Used by sql_yacc */
    };
    using column_flags  = ::cppcore::simple_flags<column_flag>;

    enum class client_flag : uint
    {
        MySQL               = CLIENT_MYSQL,
        FoundRows           = CLIENT_FOUND_ROWS,
        LongFlag            = CLIENT_LONG_FLAG,
        ConnectWithDB       = CLIENT_CONNECT_WITH_DB,
        NoSchema            = CLIENT_NO_SCHEMA,
        Compress            = CLIENT_COMPRESS,
        Odbc                = CLIENT_ODBC,
        LocalFiles          = CLIENT_LOCAL_FILES,
        IgnoreSpace         = CLIENT_IGNORE_SPACE,
        Interactive         = CLIENT_INTERACTIVE,
        Ssl                 = CLIENT_SSL,
        IgnoreSigpipe       = CLIENT_IGNORE_SIGPIPE,
        Transactions        = CLIENT_TRANSACTIONS,
        Protocol41          = CLIENT_PROTOCOL_41,
        Reserved            = CLIENT_RESERVED,
        SecureConnection    = CLIENT_SECURE_CONNECTION,
        MultiStatements     = CLIENT_MULTI_STATEMENTS,
        MultiResults        = CLIENT_MULTI_RESULTS,
        Progress            = CLIENT_PROGRESS,
        SslVerifyServerCert = CLIENT_SSL_VERIFY_SERVER_CERT,
        RememberOptions     = CLIENT_REMEMBER_OPTIONS,
        PluginAuth          = CLIENT_PLUGIN_AUTH,
        SessionTracking     = CLIENT_SESSION_TRACKING,
        ConnectAttrs        = CLIENT_CONNECT_ATTRS,
    };
    using client_flags  = ::cppcore::simple_flags<client_flag>;

    enum class error_code : uint
    {
        NoError                                                     = 0,
        Unknown                                                     = std::numeric_limits<uint>::max(),

        ErrorFirst                                                  = /* 1000 */ ER_ERROR_FIRST,
        Hashchk                                                     = /* 1000 */ ER_HASHCHK,
        Nisamchk                                                    = /* 1001 */ ER_NISAMCHK,
        No                                                          = /* 1002 */ ER_NO,
        Yes                                                         = /* 1003 */ ER_YES,
        CantCreateFile                                              = /* 1004 */ ER_CANT_CREATE_FILE,
        CantCreateTable                                             = /* 1005 */ ER_CANT_CREATE_TABLE,
        CantCreateDb                                                = /* 1006 */ ER_CANT_CREATE_DB,
        DbCreateExists                                              = /* 1007 */ ER_DB_CREATE_EXISTS,
        DbDropExists                                                = /* 1008 */ ER_DB_DROP_EXISTS,
        DbDropDelete                                                = /* 1009 */ ER_DB_DROP_DELETE,
        DbDropRmdir                                                 = /* 1010 */ ER_DB_DROP_RMDIR,
        CantDeleteFile                                              = /* 1011 */ ER_CANT_DELETE_FILE,
        CantFindSystemRec                                           = /* 1012 */ ER_CANT_FIND_SYSTEM_REC,
        CantGetStat                                                 = /* 1013 */ ER_CANT_GET_STAT,
        CantGetWd                                                   = /* 1014 */ ER_CANT_GET_WD,
        CantLock                                                    = /* 1015 */ ER_CANT_LOCK,
        CantOpenFile                                                = /* 1016 */ ER_CANT_OPEN_FILE,
        FileNotFound                                                = /* 1017 */ ER_FILE_NOT_FOUND,
        CantReadDir                                                 = /* 1018 */ ER_CANT_READ_DIR,
        CantSetWd                                                   = /* 1019 */ ER_CANT_SET_WD,
        Checkread                                                   = /* 1020 */ ER_CHECKREAD,
        DiskFull                                                    = /* 1021 */ ER_DISK_FULL,
        DupKey                                                      = /* 1022 */ ER_DUP_KEY,
        ErrorOnClose                                                = /* 1023 */ ER_ERROR_ON_CLOSE,
        ErrorOnRead                                                 = /* 1024 */ ER_ERROR_ON_READ,
        ErrorOnRename                                               = /* 1025 */ ER_ERROR_ON_RENAME,
        ErrorOnWrite                                                = /* 1026 */ ER_ERROR_ON_WRITE,
        FileUsed                                                    = /* 1027 */ ER_FILE_USED,
        FilsortAbort                                                = /* 1028 */ ER_FILSORT_ABORT,
        FormNotFound                                                = /* 1029 */ ER_FORM_NOT_FOUND,
        GetErrno                                                    = /* 1030 */ ER_GET_ERRNO,
        IllegalHa                                                   = /* 1031 */ ER_ILLEGAL_HA,
        KeyNotFound                                                 = /* 1032 */ ER_KEY_NOT_FOUND,
        NotFormFile                                                 = /* 1033 */ ER_NOT_FORM_FILE,
        NotKeyfile                                                  = /* 1034 */ ER_NOT_KEYFILE,
        OldKeyfile                                                  = /* 1035 */ ER_OLD_KEYFILE,
        OpenAsReadonly                                              = /* 1036 */ ER_OPEN_AS_READONLY,
        Outofmemory                                                 = /* 1037 */ ER_OUTOFMEMORY,
        OutOfSortmemory                                             = /* 1038 */ ER_OUT_OF_SORTMEMORY,
        UnexpectedEof                                               = /* 1039 */ ER_UNEXPECTED_EOF,
        ConCountError                                               = /* 1040 */ ER_CON_COUNT_ERROR,
        OutOfResources                                              = /* 1041 */ ER_OUT_OF_RESOURCES,
        BadHostError                                                = /* 1042 */ ER_BAD_HOST_ERROR,
        HandshakeError                                              = /* 1043 */ ER_HANDSHAKE_ERROR,
        DbaccessDeniedError                                         = /* 1044 */ ER_DBACCESS_DENIED_ERROR,
        AccessDeniedError                                           = /* 1045 */ ER_ACCESS_DENIED_ERROR,
        NoDbError                                                   = /* 1046 */ ER_NO_DB_ERROR,
        UnknownComError                                             = /* 1047 */ ER_UNKNOWN_COM_ERROR,
        BadNullError                                                = /* 1048 */ ER_BAD_NULL_ERROR,
        BadDbError                                                  = /* 1049 */ ER_BAD_DB_ERROR,
        TableExistsError                                            = /* 1050 */ ER_TABLE_EXISTS_ERROR,
        BadTableError                                               = /* 1051 */ ER_BAD_TABLE_ERROR,
        NonUniqError                                                = /* 1052 */ ER_NON_UNIQ_ERROR,
        ServerShutdown                                              = /* 1053 */ ER_SERVER_SHUTDOWN,
        BadFieldError                                               = /* 1054 */ ER_BAD_FIELD_ERROR,
        WrongFieldWithGroup                                         = /* 1055 */ ER_WRONG_FIELD_WITH_GROUP,
        WrongGroupField                                             = /* 1056 */ ER_WRONG_GROUP_FIELD,
        WrongSumSelect                                              = /* 1057 */ ER_WRONG_SUM_SELECT,
        WrongValueCount                                             = /* 1058 */ ER_WRONG_VALUE_COUNT,
        TooLongIdent                                                = /* 1059 */ ER_TOO_LONG_IDENT,
        DupFieldname                                                = /* 1060 */ ER_DUP_FIELDNAME,
        DupKeyname                                                  = /* 1061 */ ER_DUP_KEYNAME,
        DupEntry                                                    = /* 1062 */ ER_DUP_ENTRY,
        WrongFieldSpec                                              = /* 1063 */ ER_WRONG_FIELD_SPEC,
        ParseError                                                  = /* 1064 */ ER_PARSE_ERROR,
        EmptyQuery                                                  = /* 1065 */ ER_EMPTY_QUERY,
        NonuniqTable                                                = /* 1066 */ ER_NONUNIQ_TABLE,
        InvalidDefault                                              = /* 1067 */ ER_INVALID_DEFAULT,
        MultiplePriKey                                              = /* 1068 */ ER_MULTIPLE_PRI_KEY,
        TooManyKeys                                                 = /* 1069 */ ER_TOO_MANY_KEYS,
        TooManyKeyParts                                             = /* 1070 */ ER_TOO_MANY_KEY_PARTS,
        TooLongKey                                                  = /* 1071 */ ER_TOO_LONG_KEY,
        KeyColumnDoesNotExits                                       = /* 1072 */ ER_KEY_COLUMN_DOES_NOT_EXITS,
        BlobUsedAsKey                                               = /* 1073 */ ER_BLOB_USED_AS_KEY,
        TooBigFieldlength                                           = /* 1074 */ ER_TOO_BIG_FIELDLENGTH,
        WrongAutoKey                                                = /* 1075 */ ER_WRONG_AUTO_KEY,
        NormalShutdown                                              = /* 1077 */ ER_NORMAL_SHUTDOWN,
        GotSignal                                                   = /* 1078 */ ER_GOT_SIGNAL,
        ShutdownComplete                                            = /* 1079 */ ER_SHUTDOWN_COMPLETE,
        ForcingClose                                                = /* 1080 */ ER_FORCING_CLOSE,
        IpsockError                                                 = /* 1081 */ ER_IPSOCK_ERROR,
        NoSuchIndex                                                 = /* 1082 */ ER_NO_SUCH_INDEX,
        WrongFieldTerminators                                       = /* 1083 */ ER_WRONG_FIELD_TERMINATORS,
        BlobsAndNoTerminated                                        = /* 1084 */ ER_BLOBS_AND_NO_TERMINATED,
        TextfileNotReadable                                         = /* 1085 */ ER_TEXTFILE_NOT_READABLE,
        FileExistsError                                             = /* 1086 */ ER_FILE_EXISTS_ERROR,
        LoadInfo                                                    = /* 1087 */ ER_LOAD_INFO,
        AlterInfo                                                   = /* 1088 */ ER_ALTER_INFO,
        WrongSubKey                                                 = /* 1089 */ ER_WRONG_SUB_KEY,
        CantRemoveAllFields                                         = /* 1090 */ ER_CANT_REMOVE_ALL_FIELDS,
        CantDropFieldOrKey                                          = /* 1091 */ ER_CANT_DROP_FIELD_OR_KEY,
        InsertInfo                                                  = /* 1092 */ ER_INSERT_INFO,
        UpdateTableUsed                                             = /* 1093 */ ER_UPDATE_TABLE_USED,
        NoSuchThread                                                = /* 1094 */ ER_NO_SUCH_THREAD,
        KillDeniedError                                             = /* 1095 */ ER_KILL_DENIED_ERROR,
        NoTablesUsed                                                = /* 1096 */ ER_NO_TABLES_USED,
        TooBigSet                                                   = /* 1097 */ ER_TOO_BIG_SET,
        NoUniqueLogfile                                             = /* 1098 */ ER_NO_UNIQUE_LOGFILE,
        TableNotLockedForWrite                                      = /* 1099 */ ER_TABLE_NOT_LOCKED_FOR_WRITE,
        TableNotLocked                                              = /* 1100 */ ER_TABLE_NOT_LOCKED,
        BlobCantHaveDefault                                         = /* 1101 */ ER_BLOB_CANT_HAVE_DEFAULT,
        WrongDbName                                                 = /* 1102 */ ER_WRONG_DB_NAME,
        WrongTableName                                              = /* 1103 */ ER_WRONG_TABLE_NAME,
        TooBigSelect                                                = /* 1104 */ ER_TOO_BIG_SELECT,
        UnknownError                                                = /* 1105 */ ER_UNKNOWN_ERROR,
        UnknownProcedure                                            = /* 1106 */ ER_UNKNOWN_PROCEDURE,
        WrongParamcountToProcedure                                  = /* 1107 */ ER_WRONG_PARAMCOUNT_TO_PROCEDURE,
        WrongParametersToProcedure                                  = /* 1108 */ ER_WRONG_PARAMETERS_TO_PROCEDURE,
        UnknownTable                                                = /* 1109 */ ER_UNKNOWN_TABLE,
        FieldSpecifiedTwice                                         = /* 1110 */ ER_FIELD_SPECIFIED_TWICE,
        InvalidGroupFuncUse                                         = /* 1111 */ ER_INVALID_GROUP_FUNC_USE,
        UnsupportedExtension                                        = /* 1112 */ ER_UNSUPPORTED_EXTENSION,
        TableMustHaveColumns                                        = /* 1113 */ ER_TABLE_MUST_HAVE_COLUMNS,
        RecordFileFull                                              = /* 1114 */ ER_RECORD_FILE_FULL,
        UnknownCharacterSet                                         = /* 1115 */ ER_UNKNOWN_CHARACTER_SET,
        TooManyTables                                               = /* 1116 */ ER_TOO_MANY_TABLES,
        TooManyFields                                               = /* 1117 */ ER_TOO_MANY_FIELDS,
        TooBigRowsize                                               = /* 1118 */ ER_TOO_BIG_ROWSIZE,
        StackOverrun                                                = /* 1119 */ ER_STACK_OVERRUN,
        WrongOuterJoin                                              = /* 1120 */ ER_WRONG_OUTER_JOIN,
        NullColumnInIndex                                           = /* 1121 */ ER_NULL_COLUMN_IN_INDEX,
        CantFindUdf                                                 = /* 1122 */ ER_CANT_FIND_UDF,
        CantInitializeUdf                                           = /* 1123 */ ER_CANT_INITIALIZE_UDF,
        UdfNoPaths                                                  = /* 1124 */ ER_UDF_NO_PATHS,
        UdfExists                                                   = /* 1125 */ ER_UDF_EXISTS,
        CantOpenLibrary                                             = /* 1126 */ ER_CANT_OPEN_LIBRARY,
        CantFindDlEntry                                             = /* 1127 */ ER_CANT_FIND_DL_ENTRY,
        FunctionNotDefined                                          = /* 1128 */ ER_FUNCTION_NOT_DEFINED,
        HostIsBlocked                                               = /* 1129 */ ER_HOST_IS_BLOCKED,
        HostNotPrivileged                                           = /* 1130 */ ER_HOST_NOT_PRIVILEGED,
        PasswordAnonymousUser                                       = /* 1131 */ ER_PASSWORD_ANONYMOUS_USER,
        PasswordNotAllowed                                          = /* 1132 */ ER_PASSWORD_NOT_ALLOWED,
        PasswordNoMatch                                             = /* 1133 */ ER_PASSWORD_NO_MATCH,
        UpdateInfo                                                  = /* 1134 */ ER_UPDATE_INFO,
        CantCreateThread                                            = /* 1135 */ ER_CANT_CREATE_THREAD,
        WrongValueCountOnRow                                        = /* 1136 */ ER_WRONG_VALUE_COUNT_ON_ROW,
        CantReopenTable                                             = /* 1137 */ ER_CANT_REOPEN_TABLE,
        InvalidUseOfNull                                            = /* 1138 */ ER_INVALID_USE_OF_NULL,
        RegexpError                                                 = /* 1139 */ ER_REGEXP_ERROR,
        MixOfGroupFuncAndFields                                     = /* 1140 */ ER_MIX_OF_GROUP_FUNC_AND_FIELDS,
        NonexistingGrant                                            = /* 1141 */ ER_NONEXISTING_GRANT,
        TableaccessDeniedError                                      = /* 1142 */ ER_TABLEACCESS_DENIED_ERROR,
        ColumnaccessDeniedError                                     = /* 1143 */ ER_COLUMNACCESS_DENIED_ERROR,
        IllegalGrantForTable                                        = /* 1144 */ ER_ILLEGAL_GRANT_FOR_TABLE,
        GrantWrongHostOrUser                                        = /* 1145 */ ER_GRANT_WRONG_HOST_OR_USER,
        NoSuchTable                                                 = /* 1146 */ ER_NO_SUCH_TABLE,
        NonexistingTableGrant                                       = /* 1147 */ ER_NONEXISTING_TABLE_GRANT,
        NotAllowedCommand                                           = /* 1148 */ ER_NOT_ALLOWED_COMMAND,
        SyntaxError                                                 = /* 1149 */ ER_SYNTAX_ERROR,
        DelayedCantChangeLock                                       = /* 1150 */ ER_DELAYED_CANT_CHANGE_LOCK,
        TooManyDelayedThreads                                       = /* 1151 */ ER_TOO_MANY_DELAYED_THREADS,
        AbortingConnection                                          = /* 1152 */ ER_ABORTING_CONNECTION,
        NetPacketTooLarge                                           = /* 1153 */ ER_NET_PACKET_TOO_LARGE,
        NetReadErrorFromPipe                                        = /* 1154 */ ER_NET_READ_ERROR_FROM_PIPE,
        NetFcntlError                                               = /* 1155 */ ER_NET_FCNTL_ERROR,
        NetPacketsOutOfOrder                                        = /* 1156 */ ER_NET_PACKETS_OUT_OF_ORDER,
        NetUncompressError                                          = /* 1157 */ ER_NET_UNCOMPRESS_ERROR,
        NetReadError                                                = /* 1158 */ ER_NET_READ_ERROR,
        NetReadInterrupted                                          = /* 1159 */ ER_NET_READ_INTERRUPTED,
        NetErrorOnWrite                                             = /* 1160 */ ER_NET_ERROR_ON_WRITE,
        NetWriteInterrupted                                         = /* 1161 */ ER_NET_WRITE_INTERRUPTED,
        TooLongString                                               = /* 1162 */ ER_TOO_LONG_STRING,
        TableCantHandleBlob                                         = /* 1163 */ ER_TABLE_CANT_HANDLE_BLOB,
        TableCantHandleAutoIncrement                                = /* 1164 */ ER_TABLE_CANT_HANDLE_AUTO_INCREMENT,
        DelayedInsertTableLocked                                    = /* 1165 */ ER_DELAYED_INSERT_TABLE_LOCKED,
        WrongColumnName                                             = /* 1166 */ ER_WRONG_COLUMN_NAME,
        WrongKeyColumn                                              = /* 1167 */ ER_WRONG_KEY_COLUMN,
        WrongMrgTable                                               = /* 1168 */ ER_WRONG_MRG_TABLE,
        DupUnique                                                   = /* 1169 */ ER_DUP_UNIQUE,
        BlobKeyWithoutLength                                        = /* 1170 */ ER_BLOB_KEY_WITHOUT_LENGTH,
        PrimaryCantHaveNull                                         = /* 1171 */ ER_PRIMARY_CANT_HAVE_NULL,
        TooManyRows                                                 = /* 1172 */ ER_TOO_MANY_ROWS,
        RequiresPrimaryKey                                          = /* 1173 */ ER_REQUIRES_PRIMARY_KEY,
        NoRaidCompiled                                              = /* 1174 */ ER_NO_RAID_COMPILED,
        UpdateWithoutKeyInSafeMode                                  = /* 1175 */ ER_UPDATE_WITHOUT_KEY_IN_SAFE_MODE,
        KeyDoesNotExits                                             = /* 1176 */ ER_KEY_DOES_NOT_EXITS,
        CheckNoSuchTable                                            = /* 1177 */ ER_CHECK_NO_SUCH_TABLE,
        CheckNotImplemented                                         = /* 1178 */ ER_CHECK_NOT_IMPLEMENTED,
        CantDoThisDuringAnTransaction                               = /* 1179 */ ER_CANT_DO_THIS_DURING_AN_TRANSACTION,
        ErrorDuringCommit                                           = /* 1180 */ ER_ERROR_DURING_COMMIT,
        ErrorDuringRollback                                         = /* 1181 */ ER_ERROR_DURING_ROLLBACK,
        ErrorDuringFlushLogs                                        = /* 1182 */ ER_ERROR_DURING_FLUSH_LOGS,
        ErrorDuringCheckpoint                                       = /* 1183 */ ER_ERROR_DURING_CHECKPOINT,
        NewAbortingConnection                                       = /* 1184 */ ER_NEW_ABORTING_CONNECTION,
        FlushMasterBinlogClosed                                     = /* 1186 */ ER_FLUSH_MASTER_BINLOG_CLOSED,
        IndexRebuild                                                = /* 1187 */ ER_INDEX_REBUILD,
        Master                                                      = /* 1188 */ ER_MASTER,
        MasterNetRead                                               = /* 1189 */ ER_MASTER_NET_READ,
        MasterNetWrite                                              = /* 1190 */ ER_MASTER_NET_WRITE,
        FtMatchingKeyNotFound                                       = /* 1191 */ ER_FT_MATCHING_KEY_NOT_FOUND,
        LockOrActiveTransaction                                     = /* 1192 */ ER_LOCK_OR_ACTIVE_TRANSACTION,
        UnknownSystemVariable                                       = /* 1193 */ ER_UNKNOWN_SYSTEM_VARIABLE,
        CrashedOnUsage                                              = /* 1194 */ ER_CRASHED_ON_USAGE,
        CrashedOnRepair                                             = /* 1195 */ ER_CRASHED_ON_REPAIR,
        WarningNotCompleteRollback                                  = /* 1196 */ ER_WARNING_NOT_COMPLETE_ROLLBACK,
        TransCacheFull                                              = /* 1197 */ ER_TRANS_CACHE_FULL,
        SlaveMustStop                                               = /* 1198 */ ER_SLAVE_MUST_STOP,
        SlaveNotRunning                                             = /* 1199 */ ER_SLAVE_NOT_RUNNING,
        BadSlave                                                    = /* 1200 */ ER_BAD_SLAVE,
        MasterInfo                                                  = /* 1201 */ ER_MASTER_INFO,
        SlaveThread                                                 = /* 1202 */ ER_SLAVE_THREAD,
        TooManyUserConnections                                      = /* 1203 */ ER_TOO_MANY_USER_CONNECTIONS,
        SetConstantsOnly                                            = /* 1204 */ ER_SET_CONSTANTS_ONLY,
        LockWaitTimeout                                             = /* 1205 */ ER_LOCK_WAIT_TIMEOUT,
        LockTableFull                                               = /* 1206 */ ER_LOCK_TABLE_FULL,
        ReadOnlyTransaction                                         = /* 1207 */ ER_READ_ONLY_TRANSACTION,
        DropDbWithReadLock                                          = /* 1208 */ ER_DROP_DB_WITH_READ_LOCK,
        CreateDbWithReadLock                                        = /* 1209 */ ER_CREATE_DB_WITH_READ_LOCK,
        WrongArguments                                              = /* 1210 */ ER_WRONG_ARGUMENTS,
        NoPermissionToCreateUser                                    = /* 1211 */ ER_NO_PERMISSION_TO_CREATE_USER,
        UnionTablesInDifferentDir                                   = /* 1212 */ ER_UNION_TABLES_IN_DIFFERENT_DIR,
        LockDeadlock                                                = /* 1213 */ ER_LOCK_DEADLOCK,
        TableCantHandleFt                                           = /* 1214 */ ER_TABLE_CANT_HANDLE_FT,
        CannotAddForeign                                            = /* 1215 */ ER_CANNOT_ADD_FOREIGN,
        NoReferencedRow                                             = /* 1216 */ ER_NO_REFERENCED_ROW,
        RowIsReferenced                                             = /* 1217 */ ER_ROW_IS_REFERENCED,
        ConnectToMaster                                             = /* 1218 */ ER_CONNECT_TO_MASTER,
        QueryOnMaster                                               = /* 1219 */ ER_QUERY_ON_MASTER,
        ErrorWhenExecutingCommand                                   = /* 1220 */ ER_ERROR_WHEN_EXECUTING_COMMAND,
        WrongUsage                                                  = /* 1221 */ ER_WRONG_USAGE,
        WrongNumberOfColumnsInSelect                                = /* 1222 */ ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT,
        CantUpdateWithReadlock                                      = /* 1223 */ ER_CANT_UPDATE_WITH_READLOCK,
        MixingNotAllowed                                            = /* 1224 */ ER_MIXING_NOT_ALLOWED,
        DupArgument                                                 = /* 1225 */ ER_DUP_ARGUMENT,
        UserLimitReached                                            = /* 1226 */ ER_USER_LIMIT_REACHED,
        SpecificAccessDeniedError                                   = /* 1227 */ ER_SPECIFIC_ACCESS_DENIED_ERROR,
        LocalVariable                                               = /* 1228 */ ER_LOCAL_VARIABLE,
        GlobalVariable                                              = /* 1229 */ ER_GLOBAL_VARIABLE,
        NoDefault                                                   = /* 1230 */ ER_NO_DEFAULT,
        WrongValueForVar                                            = /* 1231 */ ER_WRONG_VALUE_FOR_VAR,
        WrongTypeForVar                                             = /* 1232 */ ER_WRONG_TYPE_FOR_VAR,
        VarCantBeRead                                               = /* 1233 */ ER_VAR_CANT_BE_READ,
        CantUseOptionHere                                           = /* 1234 */ ER_CANT_USE_OPTION_HERE,
        NotSupportedYet                                             = /* 1235 */ ER_NOT_SUPPORTED_YET,
        MasterFatalErrorReadingBinlog                               = /* 1236 */ ER_MASTER_FATAL_ERROR_READING_BINLOG,
        SlaveIgnoredTable                                           = /* 1237 */ ER_SLAVE_IGNORED_TABLE,
        IncorrectGlobalLocalVar                                     = /* 1238 */ ER_INCORRECT_GLOBAL_LOCAL_VAR,
        WrongFkDef                                                  = /* 1239 */ ER_WRONG_FK_DEF,
        KeyRefDoNotMatchTableRef                                    = /* 1240 */ ER_KEY_REF_DO_NOT_MATCH_TABLE_REF,
        OperandColumns                                              = /* 1241 */ ER_OPERAND_COLUMNS,
        SubqueryNo1Row                                              = /* 1242 */ ER_SUBQUERY_NO_1_ROW,
        UnknownStmtHandler                                          = /* 1243 */ ER_UNKNOWN_STMT_HANDLER,
        CorruptHelpDb                                               = /* 1244 */ ER_CORRUPT_HELP_DB,
        CyclicReference                                             = /* 1245 */ ER_CYCLIC_REFERENCE,
        AutoConvert                                                 = /* 1246 */ ER_AUTO_CONVERT,
        IllegalReference                                            = /* 1247 */ ER_ILLEGAL_REFERENCE,
        DerivedMustHaveAlias                                        = /* 1248 */ ER_DERIVED_MUST_HAVE_ALIAS,
        SelectReduced                                               = /* 1249 */ ER_SELECT_REDUCED,
        TablenameNotAllowedHere                                     = /* 1250 */ ER_TABLENAME_NOT_ALLOWED_HERE,
        NotSupportedAuthMode                                        = /* 1251 */ ER_NOT_SUPPORTED_AUTH_MODE,
        SpatialCantHaveNull                                         = /* 1252 */ ER_SPATIAL_CANT_HAVE_NULL,
        CollationCharsetMismatch                                    = /* 1253 */ ER_COLLATION_CHARSET_MISMATCH,
        SlaveWasRunning                                             = /* 1254 */ ER_SLAVE_WAS_RUNNING,
        SlaveWasNotRunning                                          = /* 1255 */ ER_SLAVE_WAS_NOT_RUNNING,
        TooBigForUncompress                                         = /* 1256 */ ER_TOO_BIG_FOR_UNCOMPRESS,
        ZlibZMemError                                               = /* 1257 */ ER_ZLIB_Z_MEM_ERROR,
        ZlibZBufError                                               = /* 1258 */ ER_ZLIB_Z_BUF_ERROR,
        ZlibZDataError                                              = /* 1259 */ ER_ZLIB_Z_DATA_ERROR,
        CutValueGroupConcat                                         = /* 1260 */ ER_CUT_VALUE_GROUP_CONCAT,
        WarnTooFewRecords                                           = /* 1261 */ ER_WARN_TOO_FEW_RECORDS,
        WarnTooManyRecords                                          = /* 1262 */ ER_WARN_TOO_MANY_RECORDS,
        WarnNullToNotnull                                           = /* 1263 */ ER_WARN_NULL_TO_NOTNULL,
        WarnDataOutOfRange                                          = /* 1264 */ ER_WARN_DATA_OUT_OF_RANGE,
        warnDataTruncated                                           = /* 1265 */ WARN_DATA_TRUNCATED,
        WarnUsingOtherHandler                                       = /* 1266 */ ER_WARN_USING_OTHER_HANDLER,
        CantAggregate2collations                                    = /* 1267 */ ER_CANT_AGGREGATE_2COLLATIONS,
        DropUser                                                    = /* 1268 */ ER_DROP_USER,
        RevokeGrants                                                = /* 1269 */ ER_REVOKE_GRANTS,
        CantAggregate3collations                                    = /* 1270 */ ER_CANT_AGGREGATE_3COLLATIONS,
        CantAggregateNcollations                                    = /* 1271 */ ER_CANT_AGGREGATE_NCOLLATIONS,
        VariableIsNotStruct                                         = /* 1272 */ ER_VARIABLE_IS_NOT_STRUCT,
        UnknownCollation                                            = /* 1273 */ ER_UNKNOWN_COLLATION,
        SlaveIgnoredSslParams                                       = /* 1274 */ ER_SLAVE_IGNORED_SSL_PARAMS,
        ServerIsInSecureAuthMode                                    = /* 1275 */ ER_SERVER_IS_IN_SECURE_AUTH_MODE,
        WarnFieldResolved                                           = /* 1276 */ ER_WARN_FIELD_RESOLVED,
        BadSlaveUntilCond                                           = /* 1277 */ ER_BAD_SLAVE_UNTIL_COND,
        MissingSkipSlave                                            = /* 1278 */ ER_MISSING_SKIP_SLAVE,
        UntilCondIgnored                                            = /* 1279 */ ER_UNTIL_COND_IGNORED,
        WrongNameForIndex                                           = /* 1280 */ ER_WRONG_NAME_FOR_INDEX,
        WrongNameForCatalog                                         = /* 1281 */ ER_WRONG_NAME_FOR_CATALOG,
        WarnQcResize                                                = /* 1282 */ ER_WARN_QC_RESIZE,
        BadFtColumn                                                 = /* 1283 */ ER_BAD_FT_COLUMN,
        UnknownKeyCache                                             = /* 1284 */ ER_UNKNOWN_KEY_CACHE,
        WarnHostnameWontWork                                        = /* 1285 */ ER_WARN_HOSTNAME_WONT_WORK,
        UnknownStorageEngine                                        = /* 1286 */ ER_UNKNOWN_STORAGE_ENGINE,
        WarnDeprecatedSyntax                                        = /* 1287 */ ER_WARN_DEPRECATED_SYNTAX,
        NonUpdatableTable                                           = /* 1288 */ ER_NON_UPDATABLE_TABLE,
        FeatureDisabled                                             = /* 1289 */ ER_FEATURE_DISABLED,
        OptionPreventsStatement                                     = /* 1290 */ ER_OPTION_PREVENTS_STATEMENT,
        DuplicatedValueInType                                       = /* 1291 */ ER_DUPLICATED_VALUE_IN_TYPE,
        TruncatedWrongValue                                         = /* 1292 */ ER_TRUNCATED_WRONG_VALUE,
        TooMuchAutoTimestampCols                                    = /* 1293 */ ER_TOO_MUCH_AUTO_TIMESTAMP_COLS,
        InvalidOnUpdate                                             = /* 1294 */ ER_INVALID_ON_UPDATE,
        UnsupportedPs                                               = /* 1295 */ ER_UNSUPPORTED_PS,
        GetErrmsg                                                   = /* 1296 */ ER_GET_ERRMSG,
        GetTemporaryErrmsg                                          = /* 1297 */ ER_GET_TEMPORARY_ERRMSG,
        UnknownTimeZone                                             = /* 1298 */ ER_UNKNOWN_TIME_ZONE,
        WarnInvalidTimestamp                                        = /* 1299 */ ER_WARN_INVALID_TIMESTAMP,
        InvalidCharacterString                                      = /* 1300 */ ER_INVALID_CHARACTER_STRING,
        WarnAllowedPacketOverflowed                                 = /* 1301 */ ER_WARN_ALLOWED_PACKET_OVERFLOWED,
        ConflictingDeclarations                                     = /* 1302 */ ER_CONFLICTING_DECLARATIONS,
        SpNoRecursiveCreate                                         = /* 1303 */ ER_SP_NO_RECURSIVE_CREATE,
        SpAlreadyExists                                             = /* 1304 */ ER_SP_ALREADY_EXISTS,
        SpDoesNotExist                                              = /* 1305 */ ER_SP_DOES_NOT_EXIST,
        SpDropFailed                                                = /* 1306 */ ER_SP_DROP_FAILED,
        SpStoreFailed                                               = /* 1307 */ ER_SP_STORE_FAILED,
        SpLilabelMismatch                                           = /* 1308 */ ER_SP_LILABEL_MISMATCH,
        SpLabelRedefine                                             = /* 1309 */ ER_SP_LABEL_REDEFINE,
        SpLabelMismatch                                             = /* 1310 */ ER_SP_LABEL_MISMATCH,
        SpUninitVar                                                 = /* 1311 */ ER_SP_UNINIT_VAR,
        SpBadselect                                                 = /* 1312 */ ER_SP_BADSELECT,
        SpBadreturn                                                 = /* 1313 */ ER_SP_BADRETURN,
        SpBadstatement                                              = /* 1314 */ ER_SP_BADSTATEMENT,
        UpdateLogDeprecatedIgnored                                  = /* 1315 */ ER_UPDATE_LOG_DEPRECATED_IGNORED,
        UpdateLogDeprecatedTranslated                               = /* 1316 */ ER_UPDATE_LOG_DEPRECATED_TRANSLATED,
        QueryInterrupted                                            = /* 1317 */ ER_QUERY_INTERRUPTED,
        SpWrongNoOfArgs                                             = /* 1318 */ ER_SP_WRONG_NO_OF_ARGS,
        SpCondMismatch                                              = /* 1319 */ ER_SP_COND_MISMATCH,
        SpNoreturn                                                  = /* 1320 */ ER_SP_NORETURN,
        SpNoreturnend                                               = /* 1321 */ ER_SP_NORETURNEND,
        SpBadCursorQuery                                            = /* 1322 */ ER_SP_BAD_CURSOR_QUERY,
        SpBadCursorSelect                                           = /* 1323 */ ER_SP_BAD_CURSOR_SELECT,
        SpCursorMismatch                                            = /* 1324 */ ER_SP_CURSOR_MISMATCH,
        SpCursorAlreadyOpen                                         = /* 1325 */ ER_SP_CURSOR_ALREADY_OPEN,
        SpCursorNotOpen                                             = /* 1326 */ ER_SP_CURSOR_NOT_OPEN,
        SpUndeclaredVar                                             = /* 1327 */ ER_SP_UNDECLARED_VAR,
        SpWrongNoOfFetchArgs                                        = /* 1328 */ ER_SP_WRONG_NO_OF_FETCH_ARGS,
        SpFetchNoData                                               = /* 1329 */ ER_SP_FETCH_NO_DATA,
        SpDupParam                                                  = /* 1330 */ ER_SP_DUP_PARAM,
        SpDupVar                                                    = /* 1331 */ ER_SP_DUP_VAR,
        SpDupCond                                                   = /* 1332 */ ER_SP_DUP_COND,
        SpDupCurs                                                   = /* 1333 */ ER_SP_DUP_CURS,
        SpCantAlter                                                 = /* 1334 */ ER_SP_CANT_ALTER,
        SpSubselectNyi                                              = /* 1335 */ ER_SP_SUBSELECT_NYI,
        StmtNotAllowedInSfOrTrg                                     = /* 1336 */ ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG,
        SpVarcondAfterCurshndlr                                     = /* 1337 */ ER_SP_VARCOND_AFTER_CURSHNDLR,
        SpCursorAfterHandler                                        = /* 1338 */ ER_SP_CURSOR_AFTER_HANDLER,
        SpCaseNotFound                                              = /* 1339 */ ER_SP_CASE_NOT_FOUND,
        FparserTooBigFile                                           = /* 1340 */ ER_FPARSER_TOO_BIG_FILE,
        FparserBadHeader                                            = /* 1341 */ ER_FPARSER_BAD_HEADER,
        FparserEofInComment                                         = /* 1342 */ ER_FPARSER_EOF_IN_COMMENT,
        FparserErrorInParameter                                     = /* 1343 */ ER_FPARSER_ERROR_IN_PARAMETER,
        FparserEofInUnknownParameter                                = /* 1344 */ ER_FPARSER_EOF_IN_UNKNOWN_PARAMETER,
        ViewNoExplain                                               = /* 1345 */ ER_VIEW_NO_EXPLAIN,
        FrmUnknownType                                              = /* 1346 */ ER_FRM_UNKNOWN_TYPE,
        WrongObject                                                 = /* 1347 */ ER_WRONG_OBJECT,
        NonupdateableColumn                                         = /* 1348 */ ER_NONUPDATEABLE_COLUMN,
        ViewSelectDerived                                           = /* 1349 */ ER_VIEW_SELECT_DERIVED,
        ViewSelectClause                                            = /* 1350 */ ER_VIEW_SELECT_CLAUSE,
        ViewSelectVariable                                          = /* 1351 */ ER_VIEW_SELECT_VARIABLE,
        ViewSelectTmptable                                          = /* 1352 */ ER_VIEW_SELECT_TMPTABLE,
        ViewWrongList                                               = /* 1353 */ ER_VIEW_WRONG_LIST,
        WarnViewMerge                                               = /* 1354 */ ER_WARN_VIEW_MERGE,
        WarnViewWithoutKey                                          = /* 1355 */ ER_WARN_VIEW_WITHOUT_KEY,
        ViewInvalid                                                 = /* 1356 */ ER_VIEW_INVALID,
        SpNoDropSp                                                  = /* 1357 */ ER_SP_NO_DROP_SP,
        SpGotoInHndlr                                               = /* 1358 */ ER_SP_GOTO_IN_HNDLR,
        TrgAlreadyExists                                            = /* 1359 */ ER_TRG_ALREADY_EXISTS,
        TrgDoesNotExist                                             = /* 1360 */ ER_TRG_DOES_NOT_EXIST,
        TrgOnViewOrTempTable                                        = /* 1361 */ ER_TRG_ON_VIEW_OR_TEMP_TABLE,
        TrgCantChangeRow                                            = /* 1362 */ ER_TRG_CANT_CHANGE_ROW,
        TrgNoSuchRowInTrg                                           = /* 1363 */ ER_TRG_NO_SUCH_ROW_IN_TRG,
        NoDefaultForField                                           = /* 1364 */ ER_NO_DEFAULT_FOR_FIELD,
        DivisionByZero                                              = /* 1365 */ ER_DIVISION_BY_ZERO,
        TruncatedWrongValueForField                                 = /* 1366 */ ER_TRUNCATED_WRONG_VALUE_FOR_FIELD,
        IllegalValueForType                                         = /* 1367 */ ER_ILLEGAL_VALUE_FOR_TYPE,
        ViewNonupdCheck                                             = /* 1368 */ ER_VIEW_NONUPD_CHECK,
        ViewCheckFailed                                             = /* 1369 */ ER_VIEW_CHECK_FAILED,
        ProcaccessDeniedError                                       = /* 1370 */ ER_PROCACCESS_DENIED_ERROR,
        RelayLogFail                                                = /* 1371 */ ER_RELAY_LOG_FAIL,
        PasswdLength                                                = /* 1372 */ ER_PASSWD_LENGTH,
        UnknownTargetBinlog                                         = /* 1373 */ ER_UNKNOWN_TARGET_BINLOG,
        IoErrLogIndexRead                                           = /* 1374 */ ER_IO_ERR_LOG_INDEX_READ,
        BinlogPurgeProhibited                                       = /* 1375 */ ER_BINLOG_PURGE_PROHIBITED,
        FseekFail                                                   = /* 1376 */ ER_FSEEK_FAIL,
        BinlogPurgeFatalErr                                         = /* 1377 */ ER_BINLOG_PURGE_FATAL_ERR,
        LogInUse                                                    = /* 1378 */ ER_LOG_IN_USE,
        LogPurgeUnknownErr                                          = /* 1379 */ ER_LOG_PURGE_UNKNOWN_ERR,
        RelayLogInit                                                = /* 1380 */ ER_RELAY_LOG_INIT,
        NoBinaryLogging                                             = /* 1381 */ ER_NO_BINARY_LOGGING,
        ReservedSyntax                                              = /* 1382 */ ER_RESERVED_SYNTAX,
        WsasFailed                                                  = /* 1383 */ ER_WSAS_FAILED,
        DiffGroupsProc                                              = /* 1384 */ ER_DIFF_GROUPS_PROC,
        NoGroupForProc                                              = /* 1385 */ ER_NO_GROUP_FOR_PROC,
        OrderWithProc                                               = /* 1386 */ ER_ORDER_WITH_PROC,
        LoggingProhibitChangingOf                                   = /* 1387 */ ER_LOGGING_PROHIBIT_CHANGING_OF,
        NoFileMapping                                               = /* 1388 */ ER_NO_FILE_MAPPING,
        WrongMagic                                                  = /* 1389 */ ER_WRONG_MAGIC,
        PsManyParam                                                 = /* 1390 */ ER_PS_MANY_PARAM,
        KeyPart0                                                    = /* 1391 */ ER_KEY_PART_0,
        ViewChecksum                                                = /* 1392 */ ER_VIEW_CHECKSUM,
        ViewMultiupdate                                             = /* 1393 */ ER_VIEW_MULTIUPDATE,
        ViewNoInsertFieldList                                       = /* 1394 */ ER_VIEW_NO_INSERT_FIELD_LIST,
        ViewDeleteMergeView                                         = /* 1395 */ ER_VIEW_DELETE_MERGE_VIEW,
        CannotUser                                                  = /* 1396 */ ER_CANNOT_USER,
        XaerNota                                                    = /* 1397 */ ER_XAER_NOTA,
        XaerInval                                                   = /* 1398 */ ER_XAER_INVAL,
        XaerRmfail                                                  = /* 1399 */ ER_XAER_RMFAIL,
        XaerOutside                                                 = /* 1400 */ ER_XAER_OUTSIDE,
        XaerRmerr                                                   = /* 1401 */ ER_XAER_RMERR,
        XaRbrollback                                                = /* 1402 */ ER_XA_RBROLLBACK,
        NonexistingProcGrant                                        = /* 1403 */ ER_NONEXISTING_PROC_GRANT,
        ProcAutoGrantFail                                           = /* 1404 */ ER_PROC_AUTO_GRANT_FAIL,
        ProcAutoRevokeFail                                          = /* 1405 */ ER_PROC_AUTO_REVOKE_FAIL,
        DataTooLong                                                 = /* 1406 */ ER_DATA_TOO_LONG,
        SpBadSqlstate                                               = /* 1407 */ ER_SP_BAD_SQLSTATE,
        Startup                                                     = /* 1408 */ ER_STARTUP,
        LoadFromFixedSizeRowsToVar                                  = /* 1409 */ ER_LOAD_FROM_FIXED_SIZE_ROWS_TO_VAR,
        CantCreateUserWithGrant                                     = /* 1410 */ ER_CANT_CREATE_USER_WITH_GRANT,
        WrongValueForType                                           = /* 1411 */ ER_WRONG_VALUE_FOR_TYPE,
        TableDefChanged                                             = /* 1412 */ ER_TABLE_DEF_CHANGED,
        SpDupHandler                                                = /* 1413 */ ER_SP_DUP_HANDLER,
        SpNotVarArg                                                 = /* 1414 */ ER_SP_NOT_VAR_ARG,
        SpNoRetset                                                  = /* 1415 */ ER_SP_NO_RETSET,
        CantCreateGeometryObject                                    = /* 1416 */ ER_CANT_CREATE_GEOMETRY_OBJECT,
        FailedRoutineBreakBinlog                                    = /* 1417 */ ER_FAILED_ROUTINE_BREAK_BINLOG,
        BinlogUnsafeRoutine                                         = /* 1418 */ ER_BINLOG_UNSAFE_ROUTINE,
        BinlogCreateRoutineNeedSuper                                = /* 1419 */ ER_BINLOG_CREATE_ROUTINE_NEED_SUPER,
        ExecStmtWithOpenCursor                                      = /* 1420 */ ER_EXEC_STMT_WITH_OPEN_CURSOR,
        StmtHasNoOpenCursor                                         = /* 1421 */ ER_STMT_HAS_NO_OPEN_CURSOR,
        CommitNotAllowedInSfOrTrg                                   = /* 1422 */ ER_COMMIT_NOT_ALLOWED_IN_SF_OR_TRG,
        NoDefaultForViewField                                       = /* 1423 */ ER_NO_DEFAULT_FOR_VIEW_FIELD,
        SpNoRecursion                                               = /* 1424 */ ER_SP_NO_RECURSION,
        TooBigScale                                                 = /* 1425 */ ER_TOO_BIG_SCALE,
        TooBigPrecision                                             = /* 1426 */ ER_TOO_BIG_PRECISION,
        MBiggerThanD                                                = /* 1427 */ ER_M_BIGGER_THAN_D,
        WrongLockOfSystemTable                                      = /* 1428 */ ER_WRONG_LOCK_OF_SYSTEM_TABLE,
        ConnectToForeignDataSource                                  = /* 1429 */ ER_CONNECT_TO_FOREIGN_DATA_SOURCE,
        QueryOnForeignDataSource                                    = /* 1430 */ ER_QUERY_ON_FOREIGN_DATA_SOURCE,
        ForeignDataSourceDoesntExist                                = /* 1431 */ ER_FOREIGN_DATA_SOURCE_DOESNT_EXIST,
        ForeignDataStringInvalidCantCreate                          = /* 1432 */ ER_FOREIGN_DATA_STRING_INVALID_CANT_CREATE,
        ForeignDataStringInvalid                                    = /* 1433 */ ER_FOREIGN_DATA_STRING_INVALID,
        CantCreateFederatedTable                                    = /* 1434 */ ER_CANT_CREATE_FEDERATED_TABLE,
        TrgInWrongSchema                                            = /* 1435 */ ER_TRG_IN_WRONG_SCHEMA,
        StackOverrunNeedMore                                        = /* 1436 */ ER_STACK_OVERRUN_NEED_MORE,
        TooLongBody                                                 = /* 1437 */ ER_TOO_LONG_BODY,
        WarnCantDropDefaultKeycache                                 = /* 1438 */ ER_WARN_CANT_DROP_DEFAULT_KEYCACHE,
        TooBigDisplaywidth                                          = /* 1439 */ ER_TOO_BIG_DISPLAYWIDTH,
        XaerDupid                                                   = /* 1440 */ ER_XAER_DUPID,
        DatetimeFunctionOverflow                                    = /* 1441 */ ER_DATETIME_FUNCTION_OVERFLOW,
        CantUpdateUsedTableInSfOrTrg                                = /* 1442 */ ER_CANT_UPDATE_USED_TABLE_IN_SF_OR_TRG,
        ViewPreventUpdate                                           = /* 1443 */ ER_VIEW_PREVENT_UPDATE,
        PsNoRecursion                                               = /* 1444 */ ER_PS_NO_RECURSION,
        SpCantSetAutocommit                                         = /* 1445 */ ER_SP_CANT_SET_AUTOCOMMIT,
        MalformedDefiner                                            = /* 1446 */ ER_MALFORMED_DEFINER,
        ViewFrmNoUser                                               = /* 1447 */ ER_VIEW_FRM_NO_USER,
        ViewOtherUser                                               = /* 1448 */ ER_VIEW_OTHER_USER,
        NoSuchUser                                                  = /* 1449 */ ER_NO_SUCH_USER,
        ForbidSchemaChange                                          = /* 1450 */ ER_FORBID_SCHEMA_CHANGE,
        RowIsReferenced2                                            = /* 1451 */ ER_ROW_IS_REFERENCED_2,
        NoReferencedRow2                                            = /* 1452 */ ER_NO_REFERENCED_ROW_2,
        SpBadVarShadow                                              = /* 1453 */ ER_SP_BAD_VAR_SHADOW,
        TrgNoDefiner                                                = /* 1454 */ ER_TRG_NO_DEFINER,
        OldFileFormat                                               = /* 1455 */ ER_OLD_FILE_FORMAT,
        SpRecursionLimit                                            = /* 1456 */ ER_SP_RECURSION_LIMIT,
        SpProcTableCorrupt                                          = /* 1457 */ ER_SP_PROC_TABLE_CORRUPT,
        SpWrongName                                                 = /* 1458 */ ER_SP_WRONG_NAME,
        TableNeedsUpgrade                                           = /* 1459 */ ER_TABLE_NEEDS_UPGRADE,
        SpNoAggregate                                               = /* 1460 */ ER_SP_NO_AGGREGATE,
        MaxPreparedStmtCountReached                                 = /* 1461 */ ER_MAX_PREPARED_STMT_COUNT_REACHED,
        ViewRecursive                                               = /* 1462 */ ER_VIEW_RECURSIVE,
        NonGroupingFieldUsed                                        = /* 1463 */ ER_NON_GROUPING_FIELD_USED,
        TableCantHandleSpkeys                                       = /* 1464 */ ER_TABLE_CANT_HANDLE_SPKEYS,
        NoTriggersOnSystemSchema                                    = /* 1465 */ ER_NO_TRIGGERS_ON_SYSTEM_SCHEMA,
        RemovedSpaces                                               = /* 1466 */ ER_REMOVED_SPACES,
        AutoincReadFailed                                           = /* 1467 */ ER_AUTOINC_READ_FAILED,
        Username                                                    = /* 1468 */ ER_USERNAME,
        Hostname                                                    = /* 1469 */ ER_HOSTNAME,
        WrongStringLength                                           = /* 1470 */ ER_WRONG_STRING_LENGTH,
        NonInsertableTable                                          = /* 1471 */ ER_NON_INSERTABLE_TABLE,
        AdminWrongMrgTable                                          = /* 1472 */ ER_ADMIN_WRONG_MRG_TABLE,
        TooHighLevelOfNestingForSelect                              = /* 1473 */ ER_TOO_HIGH_LEVEL_OF_NESTING_FOR_SELECT,
        NameBecomesEmpty                                            = /* 1474 */ ER_NAME_BECOMES_EMPTY,
        AmbiguousFieldTerm                                          = /* 1475 */ ER_AMBIGUOUS_FIELD_TERM,
        ForeignServerExists                                         = /* 1476 */ ER_FOREIGN_SERVER_EXISTS,
        ForeignServerDoesntExist                                    = /* 1477 */ ER_FOREIGN_SERVER_DOESNT_EXIST,
        IllegalHaCreateOption                                       = /* 1478 */ ER_ILLEGAL_HA_CREATE_OPTION,
        PartitionRequiresValuesError                                = /* 1479 */ ER_PARTITION_REQUIRES_VALUES_ERROR,
        PartitionWrongValuesError                                   = /* 1480 */ ER_PARTITION_WRONG_VALUES_ERROR,
        PartitionMaxvalueError                                      = /* 1481 */ ER_PARTITION_MAXVALUE_ERROR,
        PartitionSubpartitionError                                  = /* 1482 */ ER_PARTITION_SUBPARTITION_ERROR,
        PartitionSubpartMixError                                    = /* 1483 */ ER_PARTITION_SUBPART_MIX_ERROR,
        PartitionWrongNoPartError                                   = /* 1484 */ ER_PARTITION_WRONG_NO_PART_ERROR,
        PartitionWrongNoSubpartError                                = /* 1485 */ ER_PARTITION_WRONG_NO_SUBPART_ERROR,
        WrongExprInPartitionFuncError                               = /* 1486 */ ER_WRONG_EXPR_IN_PARTITION_FUNC_ERROR,
        NoConstExprInRangeOrListError                               = /* 1487 */ ER_NO_CONST_EXPR_IN_RANGE_OR_LIST_ERROR,
        FieldNotFoundPartError                                      = /* 1488 */ ER_FIELD_NOT_FOUND_PART_ERROR,
        ListOfFieldsOnlyInHashError                                 = /* 1489 */ ER_LIST_OF_FIELDS_ONLY_IN_HASH_ERROR,
        InconsistentPartitionInfoError                              = /* 1490 */ ER_INCONSISTENT_PARTITION_INFO_ERROR,
        PartitionFuncNotAllowedError                                = /* 1491 */ ER_PARTITION_FUNC_NOT_ALLOWED_ERROR,
        PartitionsMustBeDefinedError                                = /* 1492 */ ER_PARTITIONS_MUST_BE_DEFINED_ERROR,
        RangeNotIncreasingError                                     = /* 1493 */ ER_RANGE_NOT_INCREASING_ERROR,
        InconsistentTypeOfFunctionsError                            = /* 1494 */ ER_INCONSISTENT_TYPE_OF_FUNCTIONS_ERROR,
        MultipleDefConstInListPartError                             = /* 1495 */ ER_MULTIPLE_DEF_CONST_IN_LIST_PART_ERROR,
        PartitionEntryError                                         = /* 1496 */ ER_PARTITION_ENTRY_ERROR,
        MixHandlerError                                             = /* 1497 */ ER_MIX_HANDLER_ERROR,
        PartitionNotDefinedError                                    = /* 1498 */ ER_PARTITION_NOT_DEFINED_ERROR,
        TooManyPartitionsError                                      = /* 1499 */ ER_TOO_MANY_PARTITIONS_ERROR,
        SubpartitionError                                           = /* 1500 */ ER_SUBPARTITION_ERROR,
        CantCreateHandlerFile                                       = /* 1501 */ ER_CANT_CREATE_HANDLER_FILE,
        BlobFieldInPartFuncError                                    = /* 1502 */ ER_BLOB_FIELD_IN_PART_FUNC_ERROR,
        UniqueKeyNeedAllFieldsInPf                                  = /* 1503 */ ER_UNIQUE_KEY_NEED_ALL_FIELDS_IN_PF,
        NoPartsError                                                = /* 1504 */ ER_NO_PARTS_ERROR,
        PartitionMgmtOnNonpartitioned                               = /* 1505 */ ER_PARTITION_MGMT_ON_NONPARTITIONED,
        ForeignKeyOnPartitioned                                     = /* 1506 */ ER_FOREIGN_KEY_ON_PARTITIONED,
        DropPartitionNonExistent                                    = /* 1507 */ ER_DROP_PARTITION_NON_EXISTENT,
        DropLastPartition                                           = /* 1508 */ ER_DROP_LAST_PARTITION,
        CoalesceOnlyOnHashPartition                                 = /* 1509 */ ER_COALESCE_ONLY_ON_HASH_PARTITION,
        ReorgHashOnlyOnSameNo                                       = /* 1510 */ ER_REORG_HASH_ONLY_ON_SAME_NO,
        ReorgNoParamError                                           = /* 1511 */ ER_REORG_NO_PARAM_ERROR,
        OnlyOnRangeListPartition                                    = /* 1512 */ ER_ONLY_ON_RANGE_LIST_PARTITION,
        AddPartitionSubpartError                                    = /* 1513 */ ER_ADD_PARTITION_SUBPART_ERROR,
        AddPartitionNoNewPartition                                  = /* 1514 */ ER_ADD_PARTITION_NO_NEW_PARTITION,
        CoalescePartitionNoPartition                                = /* 1515 */ ER_COALESCE_PARTITION_NO_PARTITION,
        ReorgPartitionNotExist                                      = /* 1516 */ ER_REORG_PARTITION_NOT_EXIST,
        SameNamePartition                                           = /* 1517 */ ER_SAME_NAME_PARTITION,
        NoBinlogError                                               = /* 1518 */ ER_NO_BINLOG_ERROR,
        ConsecutiveReorgPartitions                                  = /* 1519 */ ER_CONSECUTIVE_REORG_PARTITIONS,
        ReorgOutsideRange                                           = /* 1520 */ ER_REORG_OUTSIDE_RANGE,
        PartitionFunctionFailure                                    = /* 1521 */ ER_PARTITION_FUNCTION_FAILURE,
        PartStateError                                              = /* 1522 */ ER_PART_STATE_ERROR,
        LimitedPartRange                                            = /* 1523 */ ER_LIMITED_PART_RANGE,
        PluginIsNotLoaded                                           = /* 1524 */ ER_PLUGIN_IS_NOT_LOADED,
        WrongValue                                                  = /* 1525 */ ER_WRONG_VALUE,
        NoPartitionForGivenValue                                    = /* 1526 */ ER_NO_PARTITION_FOR_GIVEN_VALUE,
        FilegroupOptionOnlyOnce                                     = /* 1527 */ ER_FILEGROUP_OPTION_ONLY_ONCE,
        CreateFilegroupFailed                                       = /* 1528 */ ER_CREATE_FILEGROUP_FAILED,
        DropFilegroupFailed                                         = /* 1529 */ ER_DROP_FILEGROUP_FAILED,
        TablespaceAutoExtendError                                   = /* 1530 */ ER_TABLESPACE_AUTO_EXTEND_ERROR,
        WrongSizeNumber                                             = /* 1531 */ ER_WRONG_SIZE_NUMBER,
        SizeOverflowError                                           = /* 1532 */ ER_SIZE_OVERFLOW_ERROR,
        AlterFilegroupFailed                                        = /* 1533 */ ER_ALTER_FILEGROUP_FAILED,
        BinlogRowLoggingFailed                                      = /* 1534 */ ER_BINLOG_ROW_LOGGING_FAILED,
        BinlogRowWrongTableDef                                      = /* 1535 */ ER_BINLOG_ROW_WRONG_TABLE_DEF,
        BinlogRowRbrToSbr                                           = /* 1536 */ ER_BINLOG_ROW_RBR_TO_SBR,
        EventAlreadyExists                                          = /* 1537 */ ER_EVENT_ALREADY_EXISTS,
        EventStoreFailed                                            = /* 1538 */ ER_EVENT_STORE_FAILED,
        EventDoesNotExist                                           = /* 1539 */ ER_EVENT_DOES_NOT_EXIST,
        EventCantAlter                                              = /* 1540 */ ER_EVENT_CANT_ALTER,
        EventDropFailed                                             = /* 1541 */ ER_EVENT_DROP_FAILED,
        EventIntervalNotPositiveOrTooBig                            = /* 1542 */ ER_EVENT_INTERVAL_NOT_POSITIVE_OR_TOO_BIG,
        EventEndsBeforeStarts                                       = /* 1543 */ ER_EVENT_ENDS_BEFORE_STARTS,
        EventExecTimeInThePast                                      = /* 1544 */ ER_EVENT_EXEC_TIME_IN_THE_PAST,
        EventOpenTableFailed                                        = /* 1545 */ ER_EVENT_OPEN_TABLE_FAILED,
        EventNeitherMExprNorMAt                                     = /* 1546 */ ER_EVENT_NEITHER_M_EXPR_NOR_M_AT,
        EventCannotDelete                                           = /* 1549 */ ER_EVENT_CANNOT_DELETE,
        EventCompileError                                           = /* 1550 */ ER_EVENT_COMPILE_ERROR,
        EventSameName                                               = /* 1551 */ ER_EVENT_SAME_NAME,
        EventDataTooLong                                            = /* 1552 */ ER_EVENT_DATA_TOO_LONG,
        DropIndexFk                                                 = /* 1553 */ ER_DROP_INDEX_FK,
        WarnDeprecatedSyntaxWithVer                                 = /* 1554 */ ER_WARN_DEPRECATED_SYNTAX_WITH_VER,
        CantWriteLockLogTable                                       = /* 1555 */ ER_CANT_WRITE_LOCK_LOG_TABLE,
        CantLockLogTable                                            = /* 1556 */ ER_CANT_LOCK_LOG_TABLE,
        ColCountDoesntMatchPleaseUpdate                             = /* 1558 */ ER_COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE,
        TempTablePreventsSwitchOutOfRbr                             = /* 1559 */ ER_TEMP_TABLE_PREVENTS_SWITCH_OUT_OF_RBR,
        StoredFunctionPreventsSwitchBinlogFormat                    = /* 1560 */ ER_STORED_FUNCTION_PREVENTS_SWITCH_BINLOG_FORMAT,
        PartitionNoTemporary                                        = /* 1562 */ ER_PARTITION_NO_TEMPORARY,
        PartitionConstDomainError                                   = /* 1563 */ ER_PARTITION_CONST_DOMAIN_ERROR,
        PartitionFunctionIsNotAllowed                               = /* 1564 */ ER_PARTITION_FUNCTION_IS_NOT_ALLOWED,
        DdlLogError                                                 = /* 1565 */ ER_DDL_LOG_ERROR,
        NullInValuesLessThan                                        = /* 1566 */ ER_NULL_IN_VALUES_LESS_THAN,
        WrongPartitionName                                          = /* 1567 */ ER_WRONG_PARTITION_NAME,
        CantChangeTxCharacteristics                                 = /* 1568 */ ER_CANT_CHANGE_TX_CHARACTERISTICS,
        DupEntryAutoincrementCase                                   = /* 1569 */ ER_DUP_ENTRY_AUTOINCREMENT_CASE,
        EventModifyQueueError                                       = /* 1570 */ ER_EVENT_MODIFY_QUEUE_ERROR,
        EventSetVarError                                            = /* 1571 */ ER_EVENT_SET_VAR_ERROR,
        PartitionMergeError                                         = /* 1572 */ ER_PARTITION_MERGE_ERROR,
        CantActivateLog                                             = /* 1573 */ ER_CANT_ACTIVATE_LOG,
        RbrNotAvailable                                             = /* 1574 */ ER_RBR_NOT_AVAILABLE,
        Base64DecodeError                                           = /* 1575 */ ER_BASE64_DECODE_ERROR,
        EventRecursionForbidden                                     = /* 1576 */ ER_EVENT_RECURSION_FORBIDDEN,
        EventsDbError                                               = /* 1577 */ ER_EVENTS_DB_ERROR,
        OnlyIntegersAllowed                                         = /* 1578 */ ER_ONLY_INTEGERS_ALLOWED,
        UnsuportedLogEngine                                         = /* 1579 */ ER_UNSUPORTED_LOG_ENGINE,
        BadLogStatement                                             = /* 1580 */ ER_BAD_LOG_STATEMENT,
        CantRenameLogTable                                          = /* 1581 */ ER_CANT_RENAME_LOG_TABLE,
        WrongParamcountToNativeFct                                  = /* 1582 */ ER_WRONG_PARAMCOUNT_TO_NATIVE_FCT,
        WrongParametersToNativeFct                                  = /* 1583 */ ER_WRONG_PARAMETERS_TO_NATIVE_FCT,
        WrongParametersToStoredFct                                  = /* 1584 */ ER_WRONG_PARAMETERS_TO_STORED_FCT,
        NativeFctNameCollision                                      = /* 1585 */ ER_NATIVE_FCT_NAME_COLLISION,
        DupEntryWithKeyName                                         = /* 1586 */ ER_DUP_ENTRY_WITH_KEY_NAME,
        BinlogPurgeEmfile                                           = /* 1587 */ ER_BINLOG_PURGE_EMFILE,
        EventCannotCreateInThePast                                  = /* 1588 */ ER_EVENT_CANNOT_CREATE_IN_THE_PAST,
        EventCannotAlterInThePast                                   = /* 1589 */ ER_EVENT_CANNOT_ALTER_IN_THE_PAST,
        SlaveIncident                                               = /* 1590 */ ER_SLAVE_INCIDENT,
        NoPartitionForGivenValueSilent                              = /* 1591 */ ER_NO_PARTITION_FOR_GIVEN_VALUE_SILENT,
        BinlogUnsafeStatement                                       = /* 1592 */ ER_BINLOG_UNSAFE_STATEMENT,
        SlaveFatalError                                             = /* 1593 */ ER_SLAVE_FATAL_ERROR,
        SlaveRelayLogReadFailure                                    = /* 1594 */ ER_SLAVE_RELAY_LOG_READ_FAILURE,
        SlaveRelayLogWriteFailure                                   = /* 1595 */ ER_SLAVE_RELAY_LOG_WRITE_FAILURE,
        SlaveCreateEventFailure                                     = /* 1596 */ ER_SLAVE_CREATE_EVENT_FAILURE,
        SlaveMasterComFailure                                       = /* 1597 */ ER_SLAVE_MASTER_COM_FAILURE,
        BinlogLoggingImpossible                                     = /* 1598 */ ER_BINLOG_LOGGING_IMPOSSIBLE,
        ViewNoCreationCtx                                           = /* 1599 */ ER_VIEW_NO_CREATION_CTX,
        ViewInvalidCreationCtx                                      = /* 1600 */ ER_VIEW_INVALID_CREATION_CTX,
        SrInvalidCreationCtx                                        = /* 1601 */ ER_SR_INVALID_CREATION_CTX,
        TrgCorruptedFile                                            = /* 1602 */ ER_TRG_CORRUPTED_FILE,
        TrgNoCreationCtx                                            = /* 1603 */ ER_TRG_NO_CREATION_CTX,
        TrgInvalidCreationCtx                                       = /* 1604 */ ER_TRG_INVALID_CREATION_CTX,
        EventInvalidCreationCtx                                     = /* 1605 */ ER_EVENT_INVALID_CREATION_CTX,
        TrgCantOpenTable                                            = /* 1606 */ ER_TRG_CANT_OPEN_TABLE,
        CantCreateSroutine                                          = /* 1607 */ ER_CANT_CREATE_SROUTINE,
        NoFormatDescriptionEventBeforeBinlogStatement               = /* 1609 */ ER_NO_FORMAT_DESCRIPTION_EVENT_BEFORE_BINLOG_STATEMENT,
        SlaveCorruptEvent                                           = /* 1610 */ ER_SLAVE_CORRUPT_EVENT,
        LoadDataInvalidColumn                                       = /* 1611 */ ER_LOAD_DATA_INVALID_COLUMN,
        LogPurgeNoFile                                              = /* 1612 */ ER_LOG_PURGE_NO_FILE,
        XaRbtimeout                                                 = /* 1613 */ ER_XA_RBTIMEOUT,
        XaRbdeadlock                                                = /* 1614 */ ER_XA_RBDEADLOCK,
        NeedReprepare                                               = /* 1615 */ ER_NEED_REPREPARE,
        DelayedNotSupported                                         = /* 1616 */ ER_DELAYED_NOT_SUPPORTED,
        warnNoMasterInfo                                            = /* 1617 */ WARN_NO_MASTER_INFO,
        warnOptionIgnored                                           = /* 1618 */ WARN_OPTION_IGNORED,
        PluginDeleteBuiltin                                         = /* 1619 */ ER_PLUGIN_DELETE_BUILTIN,
        warnPluginBusy                                              = /* 1620 */ WARN_PLUGIN_BUSY,
        VariableIsReadonly                                          = /* 1621 */ ER_VARIABLE_IS_READONLY,
        WarnEngineTransactionRollback                               = /* 1622 */ ER_WARN_ENGINE_TRANSACTION_ROLLBACK,
        SlaveHeartbeatFailure                                       = /* 1623 */ ER_SLAVE_HEARTBEAT_FAILURE,
        SlaveHeartbeatValueOutOfRange                               = /* 1624 */ ER_SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE,
        ConflictFnParseError                                        = /* 1626 */ ER_CONFLICT_FN_PARSE_ERROR,
        ExceptionsWriteError                                        = /* 1627 */ ER_EXCEPTIONS_WRITE_ERROR,
        TooLongTableComment                                         = /* 1628 */ ER_TOO_LONG_TABLE_COMMENT,
        TooLongFieldComment                                         = /* 1629 */ ER_TOO_LONG_FIELD_COMMENT,
        FuncInexistentNameCollision                                 = /* 1630 */ ER_FUNC_INEXISTENT_NAME_COLLISION,
        DatabaseName                                                = /* 1631 */ ER_DATABASE_NAME,
        TableName                                                   = /* 1632 */ ER_TABLE_NAME,
        PartitionName                                               = /* 1633 */ ER_PARTITION_NAME,
        SubpartitionName                                            = /* 1634 */ ER_SUBPARTITION_NAME,
        TemporaryName                                               = /* 1635 */ ER_TEMPORARY_NAME,
        RenamedName                                                 = /* 1636 */ ER_RENAMED_NAME,
        TooManyConcurrentTrxs                                       = /* 1637 */ ER_TOO_MANY_CONCURRENT_TRXS,
        warnNonAsciiSeparatorNotImplemented                         = /* 1638 */ WARN_NON_ASCII_SEPARATOR_NOT_IMPLEMENTED,
        DebugSyncTimeout                                            = /* 1639 */ ER_DEBUG_SYNC_TIMEOUT,
        DebugSyncHitLimit                                           = /* 1640 */ ER_DEBUG_SYNC_HIT_LIMIT,
        DupSignalSet                                                = /* 1641 */ ER_DUP_SIGNAL_SET,
        SignalWarn                                                  = /* 1642 */ ER_SIGNAL_WARN,
        SignalNotFound                                              = /* 1643 */ ER_SIGNAL_NOT_FOUND,
        SignalException                                             = /* 1644 */ ER_SIGNAL_EXCEPTION,
        ResignalWithoutActiveHandler                                = /* 1645 */ ER_RESIGNAL_WITHOUT_ACTIVE_HANDLER,
        SignalBadConditionType                                      = /* 1646 */ ER_SIGNAL_BAD_CONDITION_TYPE,
        warnCondItemTruncated                                       = /* 1647 */ WARN_COND_ITEM_TRUNCATED,
        CondItemTooLong                                             = /* 1648 */ ER_COND_ITEM_TOO_LONG,
        UnknownLocale                                               = /* 1649 */ ER_UNKNOWN_LOCALE,
        SlaveIgnoreServerIds                                        = /* 1650 */ ER_SLAVE_IGNORE_SERVER_IDS,
        QueryCacheDisabled                                          = /* 1651 */ ER_QUERY_CACHE_DISABLED,
        SameNamePartitionField                                      = /* 1652 */ ER_SAME_NAME_PARTITION_FIELD,
        PartitionColumnListError                                    = /* 1653 */ ER_PARTITION_COLUMN_LIST_ERROR,
        WrongTypeColumnValueError                                   = /* 1654 */ ER_WRONG_TYPE_COLUMN_VALUE_ERROR,
        TooManyPartitionFuncFieldsError                             = /* 1655 */ ER_TOO_MANY_PARTITION_FUNC_FIELDS_ERROR,
        MaxvalueInValuesIn                                          = /* 1656 */ ER_MAXVALUE_IN_VALUES_IN,
        TooManyValuesError                                          = /* 1657 */ ER_TOO_MANY_VALUES_ERROR,
        RowSinglePartitionFieldError                                = /* 1658 */ ER_ROW_SINGLE_PARTITION_FIELD_ERROR,
        FieldTypeNotAllowedAsPartitionField                         = /* 1659 */ ER_FIELD_TYPE_NOT_ALLOWED_AS_PARTITION_FIELD,
        PartitionFieldsTooLong                                      = /* 1660 */ ER_PARTITION_FIELDS_TOO_LONG,
        BinlogRowEngineAndStmtEngine                                = /* 1661 */ ER_BINLOG_ROW_ENGINE_AND_STMT_ENGINE,
        BinlogRowModeAndStmtEngine                                  = /* 1662 */ ER_BINLOG_ROW_MODE_AND_STMT_ENGINE,
        BinlogUnsafeAndStmtEngine                                   = /* 1663 */ ER_BINLOG_UNSAFE_AND_STMT_ENGINE,
        BinlogRowInjectionAndStmtEngine                             = /* 1664 */ ER_BINLOG_ROW_INJECTION_AND_STMT_ENGINE,
        BinlogStmtModeAndRowEngine                                  = /* 1665 */ ER_BINLOG_STMT_MODE_AND_ROW_ENGINE,
        BinlogRowInjectionAndStmtMode                               = /* 1666 */ ER_BINLOG_ROW_INJECTION_AND_STMT_MODE,
        BinlogMultipleEnginesAndSelfLoggingEngine                   = /* 1667 */ ER_BINLOG_MULTIPLE_ENGINES_AND_SELF_LOGGING_ENGINE,
        BinlogUnsafeLimit                                           = /* 1668 */ ER_BINLOG_UNSAFE_LIMIT,
        BinlogUnsafeInsertDelayed                                   = /* 1669 */ ER_BINLOG_UNSAFE_INSERT_DELAYED,
        BinlogUnsafeSystemTable                                     = /* 1670 */ ER_BINLOG_UNSAFE_SYSTEM_TABLE,
        BinlogUnsafeAutoincColumns                                  = /* 1671 */ ER_BINLOG_UNSAFE_AUTOINC_COLUMNS,
        BinlogUnsafeUdf                                             = /* 1672 */ ER_BINLOG_UNSAFE_UDF,
        BinlogUnsafeSystemVariable                                  = /* 1673 */ ER_BINLOG_UNSAFE_SYSTEM_VARIABLE,
        BinlogUnsafeSystemFunction                                  = /* 1674 */ ER_BINLOG_UNSAFE_SYSTEM_FUNCTION,
        BinlogUnsafeNontransAfterTrans                              = /* 1675 */ ER_BINLOG_UNSAFE_NONTRANS_AFTER_TRANS,
        MessageAndStatement                                         = /* 1676 */ ER_MESSAGE_AND_STATEMENT,
        SlaveConversionFailed                                       = /* 1677 */ ER_SLAVE_CONVERSION_FAILED,
        SlaveCantCreateConversion                                   = /* 1678 */ ER_SLAVE_CANT_CREATE_CONVERSION,
        InsideTransactionPreventsSwitchBinlogFormat                 = /* 1679 */ ER_INSIDE_TRANSACTION_PREVENTS_SWITCH_BINLOG_FORMAT,
        PathLength                                                  = /* 1680 */ ER_PATH_LENGTH,
        WarnDeprecatedSyntaxNoReplacement                           = /* 1681 */ ER_WARN_DEPRECATED_SYNTAX_NO_REPLACEMENT,
        WrongNativeTableStructure                                   = /* 1682 */ ER_WRONG_NATIVE_TABLE_STRUCTURE,
        WrongPerfschemaUsage                                        = /* 1683 */ ER_WRONG_PERFSCHEMA_USAGE,
        WarnISSkippedTable                                          = /* 1684 */ ER_WARN_I_S_SKIPPED_TABLE,
        InsideTransactionPreventsSwitchBinlogDirect                 = /* 1685 */ ER_INSIDE_TRANSACTION_PREVENTS_SWITCH_BINLOG_DIRECT,
        StoredFunctionPreventsSwitchBinlogDirect                    = /* 1686 */ ER_STORED_FUNCTION_PREVENTS_SWITCH_BINLOG_DIRECT,
        SpatialMustHaveGeomCol                                      = /* 1687 */ ER_SPATIAL_MUST_HAVE_GEOM_COL,
        TooLongIndexComment                                         = /* 1688 */ ER_TOO_LONG_INDEX_COMMENT,
        LockAborted                                                 = /* 1689 */ ER_LOCK_ABORTED,
        DataOutOfRange                                              = /* 1690 */ ER_DATA_OUT_OF_RANGE,
        WrongSpvarTypeInLimit                                       = /* 1691 */ ER_WRONG_SPVAR_TYPE_IN_LIMIT,
        BinlogUnsafeMultipleEnginesAndSelfLoggingEngine             = /* 1692 */ ER_BINLOG_UNSAFE_MULTIPLE_ENGINES_AND_SELF_LOGGING_ENGINE,
        BinlogUnsafeMixedStatement                                  = /* 1693 */ ER_BINLOG_UNSAFE_MIXED_STATEMENT,
        InsideTransactionPreventsSwitchSqlLogBin                    = /* 1694 */ ER_INSIDE_TRANSACTION_PREVENTS_SWITCH_SQL_LOG_BIN,
        StoredFunctionPreventsSwitchSqlLogBin                       = /* 1695 */ ER_STORED_FUNCTION_PREVENTS_SWITCH_SQL_LOG_BIN,
        FailedReadFromParFile                                       = /* 1696 */ ER_FAILED_READ_FROM_PAR_FILE,
        ValuesIsNotIntTypeError                                     = /* 1697 */ ER_VALUES_IS_NOT_INT_TYPE_ERROR,
        AccessDeniedNoPasswordError                                 = /* 1698 */ ER_ACCESS_DENIED_NO_PASSWORD_ERROR,
        SetPasswordAuthPlugin                                       = /* 1699 */ ER_SET_PASSWORD_AUTH_PLUGIN,
        GrantPluginUserExists                                       = /* 1700 */ ER_GRANT_PLUGIN_USER_EXISTS,
        TruncateIllegalFk                                           = /* 1701 */ ER_TRUNCATE_ILLEGAL_FK,
        PluginIsPermanent                                           = /* 1702 */ ER_PLUGIN_IS_PERMANENT,
        SlaveHeartbeatValueOutOfRangeMin                            = /* 1703 */ ER_SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE_MIN,
        SlaveHeartbeatValueOutOfRangeMax                            = /* 1704 */ ER_SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE_MAX,
        StmtCacheFull                                               = /* 1705 */ ER_STMT_CACHE_FULL,
        MultiUpdateKeyConflict                                      = /* 1706 */ ER_MULTI_UPDATE_KEY_CONFLICT,
        TableNeedsRebuild                                           = /* 1707 */ ER_TABLE_NEEDS_REBUILD,
        warnOptionBelowLimit                                        = /* 1708 */ WARN_OPTION_BELOW_LIMIT,
        IndexColumnTooLong                                          = /* 1709 */ ER_INDEX_COLUMN_TOO_LONG,
        ErrorInTriggerBody                                          = /* 1710 */ ER_ERROR_IN_TRIGGER_BODY,
        ErrorInUnknownTriggerBody                                   = /* 1711 */ ER_ERROR_IN_UNKNOWN_TRIGGER_BODY,
        IndexCorrupt                                                = /* 1712 */ ER_INDEX_CORRUPT,
        UndoRecordTooBig                                            = /* 1713 */ ER_UNDO_RECORD_TOO_BIG,
        BinlogUnsafeInsertIgnoreSelect                              = /* 1714 */ ER_BINLOG_UNSAFE_INSERT_IGNORE_SELECT,
        BinlogUnsafeInsertSelectUpdate                              = /* 1715 */ ER_BINLOG_UNSAFE_INSERT_SELECT_UPDATE,
        BinlogUnsafeReplaceSelect                                   = /* 1716 */ ER_BINLOG_UNSAFE_REPLACE_SELECT,
        BinlogUnsafeCreateIgnoreSelect                              = /* 1717 */ ER_BINLOG_UNSAFE_CREATE_IGNORE_SELECT,
        BinlogUnsafeCreateReplaceSelect                             = /* 1718 */ ER_BINLOG_UNSAFE_CREATE_REPLACE_SELECT,
        BinlogUnsafeUpdateIgnore                                    = /* 1719 */ ER_BINLOG_UNSAFE_UPDATE_IGNORE,
        BinlogUnsafeWriteAutoincSelect                              = /* 1722 */ ER_BINLOG_UNSAFE_WRITE_AUTOINC_SELECT,
        BinlogUnsafeCreateSelectAutoinc                             = /* 1723 */ ER_BINLOG_UNSAFE_CREATE_SELECT_AUTOINC,
        BinlogUnsafeInsertTwoKeys                                   = /* 1724 */ ER_BINLOG_UNSAFE_INSERT_TWO_KEYS,
        TableInFkCheck                                              = /* 1725 */ ER_TABLE_IN_FK_CHECK,
        BinlogUnsafeAutoincNotFirst                                 = /* 1727 */ ER_BINLOG_UNSAFE_AUTOINC_NOT_FIRST,
        CannotLoadFromTableV2                                       = /* 1728 */ ER_CANNOT_LOAD_FROM_TABLE_V2,
        MasterDelayValueOutOfRange                                  = /* 1729 */ ER_MASTER_DELAY_VALUE_OUT_OF_RANGE,
        OnlyFdAndRbrEventsAllowedInBinlogStatement                  = /* 1730 */ ER_ONLY_FD_AND_RBR_EVENTS_ALLOWED_IN_BINLOG_STATEMENT,
        PartitionExchangeDifferentOption                            = /* 1731 */ ER_PARTITION_EXCHANGE_DIFFERENT_OPTION,
        PartitionExchangePartTable                                  = /* 1732 */ ER_PARTITION_EXCHANGE_PART_TABLE,
        PartitionExchangeTempTable                                  = /* 1733 */ ER_PARTITION_EXCHANGE_TEMP_TABLE,
        PartitionInsteadOfSubpartition                              = /* 1734 */ ER_PARTITION_INSTEAD_OF_SUBPARTITION,
        UnknownPartition                                            = /* 1735 */ ER_UNKNOWN_PARTITION,
        TablesDifferentMetadata                                     = /* 1736 */ ER_TABLES_DIFFERENT_METADATA,
        RowDoesNotMatchPartition                                    = /* 1737 */ ER_ROW_DOES_NOT_MATCH_PARTITION,
        BinlogCacheSizeGreaterThanMax                               = /* 1738 */ ER_BINLOG_CACHE_SIZE_GREATER_THAN_MAX,
        WarnIndexNotApplicable                                      = /* 1739 */ ER_WARN_INDEX_NOT_APPLICABLE,
        PartitionExchangeForeignKey                                 = /* 1740 */ ER_PARTITION_EXCHANGE_FOREIGN_KEY,
        NoSuchKeyValue                                              = /* 1741 */ ER_NO_SUCH_KEY_VALUE,
        ValueTooLong                                                = /* 1742 */ ER_VALUE_TOO_LONG,
        NetworkReadEventChecksumFailure                             = /* 1743 */ ER_NETWORK_READ_EVENT_CHECKSUM_FAILURE,
        BinlogReadEventChecksumFailure                              = /* 1744 */ ER_BINLOG_READ_EVENT_CHECKSUM_FAILURE,
        BinlogStmtCacheSizeGreaterThanMax                           = /* 1745 */ ER_BINLOG_STMT_CACHE_SIZE_GREATER_THAN_MAX,
        CantUpdateTableInCreateTableSelect                          = /* 1746 */ ER_CANT_UPDATE_TABLE_IN_CREATE_TABLE_SELECT,
        PartitionClauseOnNonpartitioned                             = /* 1747 */ ER_PARTITION_CLAUSE_ON_NONPARTITIONED,
        RowDoesNotMatchGivenPartitionSet                            = /* 1748 */ ER_ROW_DOES_NOT_MATCH_GIVEN_PARTITION_SET,
        ChangeRplInfoRepositoryFailure                              = /* 1750 */ ER_CHANGE_RPL_INFO_REPOSITORY_FAILURE,
        WarningNotCompleteRollbackWithCreatedTempTable              = /* 1751 */ ER_WARNING_NOT_COMPLETE_ROLLBACK_WITH_CREATED_TEMP_TABLE,
        WarningNotCompleteRollbackWithDroppedTempTable              = /* 1752 */ ER_WARNING_NOT_COMPLETE_ROLLBACK_WITH_DROPPED_TEMP_TABLE,
        MtsFeatureIsNotSupported                                    = /* 1753 */ ER_MTS_FEATURE_IS_NOT_SUPPORTED,
        MtsUpdatedDbsGreaterMax                                     = /* 1754 */ ER_MTS_UPDATED_DBS_GREATER_MAX,
        MtsCantParallel                                             = /* 1755 */ ER_MTS_CANT_PARALLEL,
        MtsInconsistentData                                         = /* 1756 */ ER_MTS_INCONSISTENT_DATA,
        FulltextNotSupportedWithPartitioning                        = /* 1757 */ ER_FULLTEXT_NOT_SUPPORTED_WITH_PARTITIONING,
        DaInvalidConditionNumber                                    = /* 1758 */ ER_DA_INVALID_CONDITION_NUMBER,
        InsecurePlainText                                           = /* 1759 */ ER_INSECURE_PLAIN_TEXT,
        InsecureChangeMaster                                        = /* 1760 */ ER_INSECURE_CHANGE_MASTER,
        ForeignDuplicateKeyWithChildInfo                            = /* 1761 */ ER_FOREIGN_DUPLICATE_KEY_WITH_CHILD_INFO,
        ForeignDuplicateKeyWithoutChildInfo                         = /* 1762 */ ER_FOREIGN_DUPLICATE_KEY_WITHOUT_CHILD_INFO,
        SqlthreadWithSecureSlave                                    = /* 1763 */ ER_SQLTHREAD_WITH_SECURE_SLAVE,
        TableHasNoFt                                                = /* 1764 */ ER_TABLE_HAS_NO_FT,
        VariableNotSettableInSfOrTrigger                            = /* 1765 */ ER_VARIABLE_NOT_SETTABLE_IN_SF_OR_TRIGGER,
        VariableNotSettableInTransaction                            = /* 1766 */ ER_VARIABLE_NOT_SETTABLE_IN_TRANSACTION,
        GtidNextIsNotInGtidNextList                                 = /* 1767 */ ER_GTID_NEXT_IS_NOT_IN_GTID_NEXT_LIST,
        CantChangeGtidNextInTransactionWhenGtidNextListIsNull       = /* 1768 */ ER_CANT_CHANGE_GTID_NEXT_IN_TRANSACTION_WHEN_GTID_NEXT_LIST_IS_NULL,
        SetStatementCannotInvokeFunction                            = /* 1769 */ ER_SET_STATEMENT_CANNOT_INVOKE_FUNCTION,
        GtidNextCantBeAutomaticIfGtidNextListIsNonNull              = /* 1770 */ ER_GTID_NEXT_CANT_BE_AUTOMATIC_IF_GTID_NEXT_LIST_IS_NON_NULL,
        SkippingLoggedTransaction                                   = /* 1771 */ ER_SKIPPING_LOGGED_TRANSACTION,
        MalformedGtidSetSpecification                               = /* 1772 */ ER_MALFORMED_GTID_SET_SPECIFICATION,
        MalformedGtidSetEncoding                                    = /* 1773 */ ER_MALFORMED_GTID_SET_ENCODING,
        MalformedGtidSpecification                                  = /* 1774 */ ER_MALFORMED_GTID_SPECIFICATION,
        GnoExhausted                                                = /* 1775 */ ER_GNO_EXHAUSTED,
        BadSlaveAutoPosition                                        = /* 1776 */ ER_BAD_SLAVE_AUTO_POSITION,
        AutoPositionRequiresGtidModeOn                              = /* 1777 */ ER_AUTO_POSITION_REQUIRES_GTID_MODE_ON,
        CantDoImplicitCommitInTrxWhenGtidNextIsSet                  = /* 1778 */ ER_CANT_DO_IMPLICIT_COMMIT_IN_TRX_WHEN_GTID_NEXT_IS_SET,
        GtidMode2Or3RequiresEnforceGtidConsistencyOn                = /* 1779 */ ER_GTID_MODE_2_OR_3_REQUIRES_ENFORCE_GTID_CONSISTENCY_ON,
        GtidModeRequiresBinlog                                      = /* 1780 */ ER_GTID_MODE_REQUIRES_BINLOG,
        CantSetGtidNextToGtidWhenGtidModeIsOff                      = /* 1781 */ ER_CANT_SET_GTID_NEXT_TO_GTID_WHEN_GTID_MODE_IS_OFF,
        CantSetGtidNextToAnonymousWhenGtidModeIsOn                  = /* 1782 */ ER_CANT_SET_GTID_NEXT_TO_ANONYMOUS_WHEN_GTID_MODE_IS_ON,
        CantSetGtidNextListToNonNullWhenGtidModeIsOff               = /* 1783 */ ER_CANT_SET_GTID_NEXT_LIST_TO_NON_NULL_WHEN_GTID_MODE_IS_OFF,
        FoundGtidEventWhenGtidModeIsOff                             = /* 1784 */ ER_FOUND_GTID_EVENT_WHEN_GTID_MODE_IS_OFF,
        GtidUnsafeNonTransactionalTable                             = /* 1785 */ ER_GTID_UNSAFE_NON_TRANSACTIONAL_TABLE,
        GtidUnsafeCreateSelect                                      = /* 1786 */ ER_GTID_UNSAFE_CREATE_SELECT,
        GtidUnsafeCreateDropTemporaryTableInTransaction             = /* 1787 */ ER_GTID_UNSAFE_CREATE_DROP_TEMPORARY_TABLE_IN_TRANSACTION,
        GtidModeCanOnlyChangeOneStepAtATime                         = /* 1788 */ ER_GTID_MODE_CAN_ONLY_CHANGE_ONE_STEP_AT_A_TIME,
        MasterHasPurgedRequiredGtids                                = /* 1789 */ ER_MASTER_HAS_PURGED_REQUIRED_GTIDS,
        CantSetGtidNextWhenOwningGtid                               = /* 1790 */ ER_CANT_SET_GTID_NEXT_WHEN_OWNING_GTID,
        UnknownExplainFormat                                        = /* 1791 */ ER_UNKNOWN_EXPLAIN_FORMAT,
        CantExecuteInReadOnlyTransaction                            = /* 1792 */ ER_CANT_EXECUTE_IN_READ_ONLY_TRANSACTION,
        TooLongTablePartitionComment                                = /* 1793 */ ER_TOO_LONG_TABLE_PARTITION_COMMENT,
        SlaveConfiguration                                          = /* 1794 */ ER_SLAVE_CONFIGURATION,
        InnodbFtLimit                                               = /* 1795 */ ER_INNODB_FT_LIMIT,
        InnodbNoFtTempTable                                         = /* 1796 */ ER_INNODB_NO_FT_TEMP_TABLE,
        InnodbFtWrongDocidColumn                                    = /* 1797 */ ER_INNODB_FT_WRONG_DOCID_COLUMN,
        InnodbFtWrongDocidIndex                                     = /* 1798 */ ER_INNODB_FT_WRONG_DOCID_INDEX,
        InnodbOnlineLogTooBig                                       = /* 1799 */ ER_INNODB_ONLINE_LOG_TOO_BIG,
        UnknownAlterAlgorithm                                       = /* 1800 */ ER_UNKNOWN_ALTER_ALGORITHM,
        UnknownAlterLock                                            = /* 1801 */ ER_UNKNOWN_ALTER_LOCK,
        MtsChangeMasterCantRunWithGaps                              = /* 1802 */ ER_MTS_CHANGE_MASTER_CANT_RUN_WITH_GAPS,
        MtsRecoveryFailure                                          = /* 1803 */ ER_MTS_RECOVERY_FAILURE,
        MtsResetWorkers                                             = /* 1804 */ ER_MTS_RESET_WORKERS,
        ColCountDoesntMatchCorruptedV2                              = /* 1805 */ ER_COL_COUNT_DOESNT_MATCH_CORRUPTED_V2,
        SlaveSilentRetryTransaction                                 = /* 1806 */ ER_SLAVE_SILENT_RETRY_TRANSACTION,
        DiscardFkChecksRunning                                      = /* 1807 */ ER_DISCARD_FK_CHECKS_RUNNING,
        TableSchemaMismatch                                         = /* 1808 */ ER_TABLE_SCHEMA_MISMATCH,
        TableInSystemTablespace                                     = /* 1809 */ ER_TABLE_IN_SYSTEM_TABLESPACE,
        IoReadError                                                 = /* 1810 */ ER_IO_READ_ERROR,
        IoWriteError                                                = /* 1811 */ ER_IO_WRITE_ERROR,
        TablespaceMissing                                           = /* 1812 */ ER_TABLESPACE_MISSING,
        TablespaceExists                                            = /* 1813 */ ER_TABLESPACE_EXISTS,
        TablespaceDiscarded                                         = /* 1814 */ ER_TABLESPACE_DISCARDED,
        InternalError                                               = /* 1815 */ ER_INTERNAL_ERROR,
        InnodbImportError                                           = /* 1816 */ ER_INNODB_IMPORT_ERROR,
        InnodbIndexCorrupt                                          = /* 1817 */ ER_INNODB_INDEX_CORRUPT,
        InvalidYearColumnLength                                     = /* 1818 */ ER_INVALID_YEAR_COLUMN_LENGTH,
        NotValidPassword                                            = /* 1819 */ ER_NOT_VALID_PASSWORD,
        MustChangePassword                                          = /* 1820 */ ER_MUST_CHANGE_PASSWORD,
        FkNoIndexChild                                              = /* 1821 */ ER_FK_NO_INDEX_CHILD,
        FkNoIndexParent                                             = /* 1822 */ ER_FK_NO_INDEX_PARENT,
        FkFailAddSystem                                             = /* 1823 */ ER_FK_FAIL_ADD_SYSTEM,
        FkCannotOpenParent                                          = /* 1824 */ ER_FK_CANNOT_OPEN_PARENT,
        FkIncorrectOption                                           = /* 1825 */ ER_FK_INCORRECT_OPTION,
        DupConstraintName                                           = /* 1826 */ ER_DUP_CONSTRAINT_NAME,
        PasswordFormat                                              = /* 1827 */ ER_PASSWORD_FORMAT,
        FkColumnCannotDrop                                          = /* 1828 */ ER_FK_COLUMN_CANNOT_DROP,
        FkColumnCannotDropChild                                     = /* 1829 */ ER_FK_COLUMN_CANNOT_DROP_CHILD,
        FkColumnNotNull                                             = /* 1830 */ ER_FK_COLUMN_NOT_NULL,
        DupIndex                                                    = /* 1831 */ ER_DUP_INDEX,
        FkColumnCannotChange                                        = /* 1832 */ ER_FK_COLUMN_CANNOT_CHANGE,
        FkColumnCannotChangeChild                                   = /* 1833 */ ER_FK_COLUMN_CANNOT_CHANGE_CHILD,
        FkCannotDeleteParent                                        = /* 1834 */ ER_FK_CANNOT_DELETE_PARENT,
        MalformedPacket                                             = /* 1835 */ ER_MALFORMED_PACKET,
        ReadOnlyMode                                                = /* 1836 */ ER_READ_ONLY_MODE,
        GtidNextTypeUndefinedGroup                                  = /* 1837 */ ER_GTID_NEXT_TYPE_UNDEFINED_GROUP,
        VariableNotSettableInSp                                     = /* 1838 */ ER_VARIABLE_NOT_SETTABLE_IN_SP,
        CantSetGtidPurgedWhenGtidModeIsOff                          = /* 1839 */ ER_CANT_SET_GTID_PURGED_WHEN_GTID_MODE_IS_OFF,
        CantSetGtidPurgedWhenGtidExecutedIsNotEmpty                 = /* 1840 */ ER_CANT_SET_GTID_PURGED_WHEN_GTID_EXECUTED_IS_NOT_EMPTY,
        CantSetGtidPurgedWhenOwnedGtidsIsNotEmpty                   = /* 1841 */ ER_CANT_SET_GTID_PURGED_WHEN_OWNED_GTIDS_IS_NOT_EMPTY,
        GtidPurgedWasChanged                                        = /* 1842 */ ER_GTID_PURGED_WAS_CHANGED,
        GtidExecutedWasChanged                                      = /* 1843 */ ER_GTID_EXECUTED_WAS_CHANGED,
        BinlogStmtModeAndNoReplTables                               = /* 1844 */ ER_BINLOG_STMT_MODE_AND_NO_REPL_TABLES,
        AlterOperationNotSupported                                  = /* 1845 */ ER_ALTER_OPERATION_NOT_SUPPORTED,
        AlterOperationNotSupportedReason                            = /* 1846 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON,
        AlterOperationNotSupportedReasonCopy                        = /* 1847 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_COPY,
        AlterOperationNotSupportedReasonPartition                   = /* 1848 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_PARTITION,
        AlterOperationNotSupportedReasonFkRename                    = /* 1849 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_FK_RENAME,
        AlterOperationNotSupportedReasonColumnType                  = /* 1850 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_COLUMN_TYPE,
        AlterOperationNotSupportedReasonFkCheck                     = /* 1851 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_FK_CHECK,
        AlterOperationNotSupportedReasonIgnore                      = /* 1852 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_IGNORE,
        AlterOperationNotSupportedReasonNopk                        = /* 1853 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_NOPK,
        AlterOperationNotSupportedReasonAutoinc                     = /* 1854 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_AUTOINC,
        AlterOperationNotSupportedReasonHiddenFts                   = /* 1855 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_HIDDEN_FTS,
        AlterOperationNotSupportedReasonChangeFts                   = /* 1856 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_CHANGE_FTS,
        AlterOperationNotSupportedReasonFts                         = /* 1857 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_FTS,
        SqlSlaveSkipCounterNotSettableInGtidMode                    = /* 1858 */ ER_SQL_SLAVE_SKIP_COUNTER_NOT_SETTABLE_IN_GTID_MODE,
        DupUnknownInIndex                                           = /* 1859 */ ER_DUP_UNKNOWN_IN_INDEX,
        IdentCausesTooLongPath                                      = /* 1860 */ ER_IDENT_CAUSES_TOO_LONG_PATH,
        AlterOperationNotSupportedReasonNotNull                     = /* 1861 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_NOT_NULL,
        MustChangePasswordLogin                                     = /* 1862 */ ER_MUST_CHANGE_PASSWORD_LOGIN,
        RowInWrongPartition                                         = /* 1863 */ ER_ROW_IN_WRONG_PARTITION,
        MtsEventBiggerPendingJobsSizeMax                            = /* 1864 */ ER_MTS_EVENT_BIGGER_PENDING_JOBS_SIZE_MAX,
        InnodbNoFtUsesParser                                        = /* 1865 */ ER_INNODB_NO_FT_USES_PARSER,
        BinlogLogicalCorruption                                     = /* 1866 */ ER_BINLOG_LOGICAL_CORRUPTION,
        WarnPurgeLogInUse                                           = /* 1867 */ ER_WARN_PURGE_LOG_IN_USE,
        WarnPurgeLogIsActive                                        = /* 1868 */ ER_WARN_PURGE_LOG_IS_ACTIVE,
        AutoIncrementConflict                                       = /* 1869 */ ER_AUTO_INCREMENT_CONFLICT,
        warnOnBlockholeInRbr                                        = /* 1870 */ WARN_ON_BLOCKHOLE_IN_RBR,
        SlaveMiInitRepository                                       = /* 1871 */ ER_SLAVE_MI_INIT_REPOSITORY,
        SlaveRliInitRepository                                      = /* 1872 */ ER_SLAVE_RLI_INIT_REPOSITORY,
        AccessDeniedChangeUserError                                 = /* 1873 */ ER_ACCESS_DENIED_CHANGE_USER_ERROR,
        InnodbReadOnly                                              = /* 1874 */ ER_INNODB_READ_ONLY,
        StopSlaveSqlThreadTimeout                                   = /* 1875 */ ER_STOP_SLAVE_SQL_THREAD_TIMEOUT,
        StopSlaveIoThreadTimeout                                    = /* 1876 */ ER_STOP_SLAVE_IO_THREAD_TIMEOUT,
        TableCorrupt                                                = /* 1877 */ ER_TABLE_CORRUPT,
        TempFileWriteFailure                                        = /* 1878 */ ER_TEMP_FILE_WRITE_FAILURE,
        InnodbFtAuxNotHexId                                         = /* 1879 */ ER_INNODB_FT_AUX_NOT_HEX_ID,
        LastMysqlErrorMessage                                       = /* 1880 */ ER_LAST_MYSQL_ERROR_MESSAGE,
        ErrorLastSection1                                           = /* 1880 */ ER_ERROR_LAST_SECTION_1,

        /* new section */

        ErrorFirstSection2                                          = /* 1900 */ ER_ERROR_FIRST_SECTION_2,
        GeneratedColumnFunctionIsNotAllowed                         = /* 1901 */ ER_GENERATED_COLUMN_FUNCTION_IS_NOT_ALLOWED,
        PrimaryKeyBasedOnGeneratedColumn                            = /* 1903 */ ER_PRIMARY_KEY_BASED_ON_GENERATED_COLUMN,
        KeyBasedOnGeneratedVirtualColumn                            = /* 1904 */ ER_KEY_BASED_ON_GENERATED_VIRTUAL_COLUMN,
        WrongFkOptionForGeneratedColumn                             = /* 1905 */ ER_WRONG_FK_OPTION_FOR_GENERATED_COLUMN,
        WarningNonDefaultValueForGeneratedColumn                    = /* 1906 */ ER_WARNING_NON_DEFAULT_VALUE_FOR_GENERATED_COLUMN,
        UnsupportedActionOnGeneratedColumn                          = /* 1907 */ ER_UNSUPPORTED_ACTION_ON_GENERATED_COLUMN,
        UnsupportedEngineForGeneratedColumns                        = /* 1910 */ ER_UNSUPPORTED_ENGINE_FOR_GENERATED_COLUMNS,
        UnknownOption                                               = /* 1911 */ ER_UNKNOWN_OPTION,
        BadOptionValue                                              = /* 1912 */ ER_BAD_OPTION_VALUE,
        DataOverflow                                                = /* 1916 */ ER_DATA_OVERFLOW,
        DataTruncated                                               = /* 1917 */ ER_DATA_TRUNCATED,
        BadData                                                     = /* 1918 */ ER_BAD_DATA,
        DynColWrongFormat                                           = /* 1919 */ ER_DYN_COL_WRONG_FORMAT,
        DynColImplementationLimit                                   = /* 1920 */ ER_DYN_COL_IMPLEMENTATION_LIMIT,
        DynColData                                                  = /* 1921 */ ER_DYN_COL_DATA,
        DynColWrongCharset                                          = /* 1922 */ ER_DYN_COL_WRONG_CHARSET,
        IllegalSubqueryOptimizerSwitches                            = /* 1923 */ ER_ILLEGAL_SUBQUERY_OPTIMIZER_SWITCHES,
        QueryCacheIsDisabled                                        = /* 1924 */ ER_QUERY_CACHE_IS_DISABLED,
        QueryCacheIsGlobalyDisabled                                 = /* 1925 */ ER_QUERY_CACHE_IS_GLOBALY_DISABLED,
        ViewOrderbyIgnored                                          = /* 1926 */ ER_VIEW_ORDERBY_IGNORED,
        ConnectionKilled                                            = /* 1927 */ ER_CONNECTION_KILLED,
        InsideTransactionPreventsSwitchSkipReplication              = /* 1929 */ ER_INSIDE_TRANSACTION_PREVENTS_SWITCH_SKIP_REPLICATION,
        StoredFunctionPreventsSwitchSkipReplication                 = /* 1930 */ ER_STORED_FUNCTION_PREVENTS_SWITCH_SKIP_REPLICATION,
        QueryExceededRowsExaminedLimit                              = /* 1931 */ ER_QUERY_EXCEEDED_ROWS_EXAMINED_LIMIT,
        NoSuchTableInEngine                                         = /* 1932 */ ER_NO_SUCH_TABLE_IN_ENGINE,
        TargetNotExplainable                                        = /* 1933 */ ER_TARGET_NOT_EXPLAINABLE,
        ConnectionAlreadyExists                                     = /* 1934 */ ER_CONNECTION_ALREADY_EXISTS,
        MasterLogPrefix                                             = /* 1935 */ ER_MASTER_LOG_PREFIX,
        CantStartStopSlave                                          = /* 1936 */ ER_CANT_START_STOP_SLAVE,
        SlaveStarted                                                = /* 1937 */ ER_SLAVE_STARTED,
        SlaveStopped                                                = /* 1938 */ ER_SLAVE_STOPPED,
        SqlDiscoverError                                            = /* 1939 */ ER_SQL_DISCOVER_ERROR,
        FailedGtidStateInit                                         = /* 1940 */ ER_FAILED_GTID_STATE_INIT,
        IncorrectGtidState                                          = /* 1941 */ ER_INCORRECT_GTID_STATE,
        CannotUpdateGtidState                                       = /* 1942 */ ER_CANNOT_UPDATE_GTID_STATE,
        DuplicateGtidDomain                                         = /* 1943 */ ER_DUPLICATE_GTID_DOMAIN,
        GtidOpenTableFailed                                         = /* 1944 */ ER_GTID_OPEN_TABLE_FAILED,
        GtidPositionNotFoundInBinlog                                = /* 1945 */ ER_GTID_POSITION_NOT_FOUND_IN_BINLOG,
        CannotLoadSlaveGtidState                                    = /* 1946 */ ER_CANNOT_LOAD_SLAVE_GTID_STATE,
        MasterGtidPosConflictsWithBinlog                            = /* 1947 */ ER_MASTER_GTID_POS_CONFLICTS_WITH_BINLOG,
        MasterGtidPosMissingDomain                                  = /* 1948 */ ER_MASTER_GTID_POS_MISSING_DOMAIN,
        UntilRequiresUsingGtid                                      = /* 1949 */ ER_UNTIL_REQUIRES_USING_GTID,
        GtidStrictOutOfOrder                                        = /* 1950 */ ER_GTID_STRICT_OUT_OF_ORDER,
        GtidStartFromBinlogHole                                     = /* 1951 */ ER_GTID_START_FROM_BINLOG_HOLE,
        SlaveUnexpectedMasterSwitch                                 = /* 1952 */ ER_SLAVE_UNEXPECTED_MASTER_SWITCH,
        InsideTransactionPreventsSwitchGtidDomainIdSeqNo            = /* 1953 */ ER_INSIDE_TRANSACTION_PREVENTS_SWITCH_GTID_DOMAIN_ID_SEQ_NO,
        StoredFunctionPreventsSwitchGtidDomainIdSeqNo               = /* 1954 */ ER_STORED_FUNCTION_PREVENTS_SWITCH_GTID_DOMAIN_ID_SEQ_NO,
        GtidPositionNotFoundInBinlog2                               = /* 1955 */ ER_GTID_POSITION_NOT_FOUND_IN_BINLOG2,
        BinlogMustBeEmpty                                           = /* 1956 */ ER_BINLOG_MUST_BE_EMPTY,
        NoSuchQuery                                                 = /* 1957 */ ER_NO_SUCH_QUERY,
        BadBase64Data                                               = /* 1958 */ ER_BAD_BASE64_DATA,
        InvalidRole                                                 = /* 1959 */ ER_INVALID_ROLE,
        InvalidCurrentUser                                          = /* 1960 */ ER_INVALID_CURRENT_USER,
        CannotGrantRole                                             = /* 1961 */ ER_CANNOT_GRANT_ROLE,
        CannotRevokeRole                                            = /* 1962 */ ER_CANNOT_REVOKE_ROLE,
        ChangeSlaveParallelThreadsActive                            = /* 1963 */ ER_CHANGE_SLAVE_PARALLEL_THREADS_ACTIVE,
        PriorCommitFailed                                           = /* 1964 */ ER_PRIOR_COMMIT_FAILED,
        ItIsAView                                                   = /* 1965 */ ER_IT_IS_A_VIEW,
        SlaveSkipNotInGtid                                          = /* 1966 */ ER_SLAVE_SKIP_NOT_IN_GTID,
        TableDefinitionTooBig                                       = /* 1967 */ ER_TABLE_DEFINITION_TOO_BIG,
        PluginInstalled                                             = /* 1968 */ ER_PLUGIN_INSTALLED,
        StatementTimeout                                            = /* 1969 */ ER_STATEMENT_TIMEOUT,
        SubqueriesNotSupported                                      = /* 1970 */ ER_SUBQUERIES_NOT_SUPPORTED,
        SetStatementNotSupported                                    = /* 1971 */ ER_SET_STATEMENT_NOT_SUPPORTED,
        UserCreateExists                                            = /* 1973 */ ER_USER_CREATE_EXISTS,
        UserDropExists                                              = /* 1974 */ ER_USER_DROP_EXISTS,
        RoleCreateExists                                            = /* 1975 */ ER_ROLE_CREATE_EXISTS,
        RoleDropExists                                              = /* 1976 */ ER_ROLE_DROP_EXISTS,
        CannotConvertCharacter                                      = /* 1977 */ ER_CANNOT_CONVERT_CHARACTER,
        InvalidDefaultValueForField                                 = /* 1978 */ ER_INVALID_DEFAULT_VALUE_FOR_FIELD,
        KillQueryDeniedError                                        = /* 1979 */ ER_KILL_QUERY_DENIED_ERROR,
        NoEisForField                                               = /* 1980 */ ER_NO_EIS_FOR_FIELD,
        WarnAggfuncDependence                                       = /* 1981 */ ER_WARN_AGGFUNC_DEPENDENCE,
        ErrorLastSection2                                           = /* 1981 */ ER_ERROR_LAST_SECTION_2,

        /* new section */

        ErrorFirstSection4                                          = /* 3000 */ ER_ERROR_FIRST_SECTION_4,
        FileCorrupt                                                 = /* 3000 */ ER_FILE_CORRUPT,
        ErrorOnMaster                                               = /* 3001 */ ER_ERROR_ON_MASTER,
        InconsistentError                                           = /* 3002 */ ER_INCONSISTENT_ERROR,
        StorageEngineNotLoaded                                      = /* 3003 */ ER_STORAGE_ENGINE_NOT_LOADED,
        GetStackedDaWithoutActiveHandler                            = /* 3004 */ ER_GET_STACKED_DA_WITHOUT_ACTIVE_HANDLER,
        WarnLegacySyntaxConverted                                   = /* 3005 */ ER_WARN_LEGACY_SYNTAX_CONVERTED,
        BinlogUnsafeFulltextPlugin                                  = /* 3006 */ ER_BINLOG_UNSAFE_FULLTEXT_PLUGIN,
        CannotDiscardTemporaryTable                                 = /* 3007 */ ER_CANNOT_DISCARD_TEMPORARY_TABLE,
        FkDepthExceeded                                             = /* 3008 */ ER_FK_DEPTH_EXCEEDED,
        ColCountDoesntMatchPleaseUpdateV2                           = /* 3009 */ ER_COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE_V2,
        WarnTriggerDoesntHaveCreated                                = /* 3010 */ ER_WARN_TRIGGER_DOESNT_HAVE_CREATED,
        ReferencedTrgDoesNotExistMysql                              = /* 3011 */ ER_REFERENCED_TRG_DOES_NOT_EXIST_MYSQL,
        ExplainNotSupported                                         = /* 3012 */ ER_EXPLAIN_NOT_SUPPORTED,
        InvalidFieldSize                                            = /* 3013 */ ER_INVALID_FIELD_SIZE,
        MissingHaCreateOption                                       = /* 3014 */ ER_MISSING_HA_CREATE_OPTION,
        EngineOutOfMemory                                           = /* 3015 */ ER_ENGINE_OUT_OF_MEMORY,
        PasswordExpireAnonymousUser                                 = /* 3016 */ ER_PASSWORD_EXPIRE_ANONYMOUS_USER,
        SlaveSqlThreadMustStop                                      = /* 3017 */ ER_SLAVE_SQL_THREAD_MUST_STOP,
        NoFtMaterializedSubquery                                    = /* 3018 */ ER_NO_FT_MATERIALIZED_SUBQUERY,
        InnodbUndoLogFull                                           = /* 3019 */ ER_INNODB_UNDO_LOG_FULL,
        InvalidArgumentForLogarithm                                 = /* 3020 */ ER_INVALID_ARGUMENT_FOR_LOGARITHM,
        SlaveChannelIoThreadMustStop                                = /* 3021 */ ER_SLAVE_CHANNEL_IO_THREAD_MUST_STOP,
        WarnOpenTempTablesMustBeZero                                = /* 3022 */ ER_WARN_OPEN_TEMP_TABLES_MUST_BE_ZERO,
        WarnOnlyMasterLogFileNoPos                                  = /* 3023 */ ER_WARN_ONLY_MASTER_LOG_FILE_NO_POS,
        QueryTimeout                                                = /* 3024 */ ER_QUERY_TIMEOUT,
        NonRoSelectDisableTimer                                     = /* 3025 */ ER_NON_RO_SELECT_DISABLE_TIMER,
        DupListEntry                                                = /* 3026 */ ER_DUP_LIST_ENTRY,
        SqlModeNoEffect                                             = /* 3027 */ ER_SQL_MODE_NO_EFFECT,
        AggregateOrderForUnion                                      = /* 3028 */ ER_AGGREGATE_ORDER_FOR_UNION,
        AggregateOrderNonAggQuery                                   = /* 3029 */ ER_AGGREGATE_ORDER_NON_AGG_QUERY,
        SlaveWorkerStoppedPreviousThdError                          = /* 3030 */ ER_SLAVE_WORKER_STOPPED_PREVIOUS_THD_ERROR,
        DontSupportSlavePreserveCommitOrder                         = /* 3031 */ ER_DONT_SUPPORT_SLAVE_PRESERVE_COMMIT_ORDER,
        ServerOfflineMode                                           = /* 3032 */ ER_SERVER_OFFLINE_MODE,
        GisDifferentSrids                                           = /* 3033 */ ER_GIS_DIFFERENT_SRIDS,
        GisUnsupportedArgument                                      = /* 3034 */ ER_GIS_UNSUPPORTED_ARGUMENT,
        GisUnknownError                                             = /* 3035 */ ER_GIS_UNKNOWN_ERROR,
        GisUnknownException                                         = /* 3036 */ ER_GIS_UNKNOWN_EXCEPTION,
        GisInvalidData                                              = /* 3037 */ ER_GIS_INVALID_DATA,
        BoostGeometryEmptyInputException                            = /* 3038 */ ER_BOOST_GEOMETRY_EMPTY_INPUT_EXCEPTION,
        BoostGeometryCentroidException                              = /* 3039 */ ER_BOOST_GEOMETRY_CENTROID_EXCEPTION,
        BoostGeometryOverlayInvalidInputException                   = /* 3040 */ ER_BOOST_GEOMETRY_OVERLAY_INVALID_INPUT_EXCEPTION,
        BoostGeometryTurnInfoException                              = /* 3041 */ ER_BOOST_GEOMETRY_TURN_INFO_EXCEPTION,
        BoostGeometrySelfIntersectionPointException                 = /* 3042 */ ER_BOOST_GEOMETRY_SELF_INTERSECTION_POINT_EXCEPTION,
        BoostGeometryUnknownException                               = /* 3043 */ ER_BOOST_GEOMETRY_UNKNOWN_EXCEPTION,
        StdBadAllocError                                            = /* 3044 */ ER_STD_BAD_ALLOC_ERROR,
        StdDomainError                                              = /* 3045 */ ER_STD_DOMAIN_ERROR,
        StdLengthError                                              = /* 3046 */ ER_STD_LENGTH_ERROR,
        StdInvalidArgument                                          = /* 3047 */ ER_STD_INVALID_ARGUMENT,
        StdOutOfRangeError                                          = /* 3048 */ ER_STD_OUT_OF_RANGE_ERROR,
        StdOverflowError                                            = /* 3049 */ ER_STD_OVERFLOW_ERROR,
        StdRangeError                                               = /* 3050 */ ER_STD_RANGE_ERROR,
        StdUnderflowError                                           = /* 3051 */ ER_STD_UNDERFLOW_ERROR,
        StdLogicError                                               = /* 3052 */ ER_STD_LOGIC_ERROR,
        StdRuntimeError                                             = /* 3053 */ ER_STD_RUNTIME_ERROR,
        StdUnknownException                                         = /* 3054 */ ER_STD_UNKNOWN_EXCEPTION,
        GisDataWrongEndianess                                       = /* 3055 */ ER_GIS_DATA_WRONG_ENDIANESS,
        ChangeMasterPasswordLength                                  = /* 3056 */ ER_CHANGE_MASTER_PASSWORD_LENGTH,
        UserLockWrongName                                           = /* 3057 */ ER_USER_LOCK_WRONG_NAME,
        UserLockDeadlock                                            = /* 3058 */ ER_USER_LOCK_DEADLOCK,
        ReplaceInaccessibleRows                                     = /* 3059 */ ER_REPLACE_INACCESSIBLE_ROWS,
        AlterOperationNotSupportedReasonGis                         = /* 3060 */ ER_ALTER_OPERATION_NOT_SUPPORTED_REASON_GIS,
        ErrorLastSection4                                           = /* 3060 */ ER_ERROR_LAST_SECTION_4,

        /* new section */

        ErrorFirstSection5                                          = /* 4000 */ ER_ERROR_FIRST_SECTION_5,
        CommultiBadcontext                                          = /* 4000 */ ER_COMMULTI_BADCONTEXT,
        BadCommandInMulti                                           = /* 4001 */ ER_BAD_COMMAND_IN_MULTI,
        WithColWrongList                                            = /* 4002 */ ER_WITH_COL_WRONG_LIST,
        TooManyDefinitionsInWithClause                              = /* 4003 */ ER_TOO_MANY_DEFINITIONS_IN_WITH_CLAUSE,
        DupQueryName                                                = /* 4004 */ ER_DUP_QUERY_NAME,
        RecursiveWithoutAnchors                                     = /* 4005 */ ER_RECURSIVE_WITHOUT_ANCHORS,
        UnacceptableMutualRecursion                                 = /* 4006 */ ER_UNACCEPTABLE_MUTUAL_RECURSION,
        RefToRecursiveWithTableInDerived                            = /* 4007 */ ER_REF_TO_RECURSIVE_WITH_TABLE_IN_DERIVED,
        NotStandardCompliantRecursive                               = /* 4008 */ ER_NOT_STANDARD_COMPLIANT_RECURSIVE,
        WrongWindowSpecName                                         = /* 4009 */ ER_WRONG_WINDOW_SPEC_NAME,
        DupWindowName                                               = /* 4010 */ ER_DUP_WINDOW_NAME,
        PartitionListInReferencingWindowSpec                        = /* 4011 */ ER_PARTITION_LIST_IN_REFERENCING_WINDOW_SPEC,
        OrderListInReferencingWindowSpec                            = /* 4012 */ ER_ORDER_LIST_IN_REFERENCING_WINDOW_SPEC,
        WindowFrameInReferencedWindowSpec                           = /* 4013 */ ER_WINDOW_FRAME_IN_REFERENCED_WINDOW_SPEC,
        BadCombinationOfWindowFrameBoundSpecs                       = /* 4014 */ ER_BAD_COMBINATION_OF_WINDOW_FRAME_BOUND_SPECS,
        WrongPlacementOfWindowFunction                              = /* 4015 */ ER_WRONG_PLACEMENT_OF_WINDOW_FUNCTION,
        WindowFunctionInWindowSpec                                  = /* 4016 */ ER_WINDOW_FUNCTION_IN_WINDOW_SPEC,
        NotAllowedWindowFrame                                       = /* 4017 */ ER_NOT_ALLOWED_WINDOW_FRAME,
        NoOrderListInWindowSpec                                     = /* 4018 */ ER_NO_ORDER_LIST_IN_WINDOW_SPEC,
        RangeFrameNeedsSimpleOrderby                                = /* 4019 */ ER_RANGE_FRAME_NEEDS_SIMPLE_ORDERBY,
        WrongTypeForRowsFrame                                       = /* 4020 */ ER_WRONG_TYPE_FOR_ROWS_FRAME,
        WrongTypeForRangeFrame                                      = /* 4021 */ ER_WRONG_TYPE_FOR_RANGE_FRAME,
        FrameExclusionNotSupported                                  = /* 4022 */ ER_FRAME_EXCLUSION_NOT_SUPPORTED,
        WindowFunctionDontHaveFrame                                 = /* 4023 */ ER_WINDOW_FUNCTION_DONT_HAVE_FRAME,
        InvalidNtileArgument                                        = /* 4024 */ ER_INVALID_NTILE_ARGUMENT,
        ConstraintFailed                                            = /* 4025 */ ER_CONSTRAINT_FAILED,
        ExpressionIsTooBig                                          = /* 4026 */ ER_EXPRESSION_IS_TOO_BIG,
        ErrorEvaluatingExpression                                   = /* 4027 */ ER_ERROR_EVALUATING_EXPRESSION,
        CalculatingDefaultValue                                     = /* 4028 */ ER_CALCULATING_DEFAULT_VALUE,
        ExpressionRefersToUninitField                               = /* 4029 */ ER_EXPRESSION_REFERS_TO_UNINIT_FIELD,
        PartitionDefaultError                                       = /* 4030 */ ER_PARTITION_DEFAULT_ERROR,
        ReferencedTrgDoesNotExist                                   = /* 4031 */ ER_REFERENCED_TRG_DOES_NOT_EXIST,
        InvalidDefaultParam                                         = /* 4032 */ ER_INVALID_DEFAULT_PARAM,
        BinlogNonSupportedBulk                                      = /* 4033 */ ER_BINLOG_NON_SUPPORTED_BULK,
        BinlogUncompressError                                       = /* 4034 */ ER_BINLOG_UNCOMPRESS_ERROR,
        JsonBadChr                                                  = /* 4035 */ ER_JSON_BAD_CHR,
        JsonNotJsonChr                                              = /* 4036 */ ER_JSON_NOT_JSON_CHR,
        JsonEos                                                     = /* 4037 */ ER_JSON_EOS,
        JsonSyntax                                                  = /* 4038 */ ER_JSON_SYNTAX,
        JsonEscaping                                                = /* 4039 */ ER_JSON_ESCAPING,
        JsonDepth                                                   = /* 4040 */ ER_JSON_DEPTH,
        JsonPathEos                                                 = /* 4041 */ ER_JSON_PATH_EOS,
        JsonPathSyntax                                              = /* 4042 */ ER_JSON_PATH_SYNTAX,
        JsonPathDepth                                               = /* 4043 */ ER_JSON_PATH_DEPTH,
        JsonPathNoWildcard                                          = /* 4044 */ ER_JSON_PATH_NO_WILDCARD,
        JsonPathArray                                               = /* 4045 */ ER_JSON_PATH_ARRAY,
        JsonOneOrAll                                                = /* 4046 */ ER_JSON_ONE_OR_ALL,
        UnsupportCompressedTemporaryTable                           = /* 4047 */ ER_UNSUPPORT_COMPRESSED_TEMPORARY_TABLE,
        GeojsonIncorrect                                            = /* 4048 */ ER_GEOJSON_INCORRECT,
        GeojsonTooFewPoints                                         = /* 4049 */ ER_GEOJSON_TOO_FEW_POINTS,
        GeojsonNotClosed                                            = /* 4050 */ ER_GEOJSON_NOT_CLOSED,
        JsonPathEmpty                                               = /* 4051 */ ER_JSON_PATH_EMPTY,
        SlaveSameId                                                 = /* 4052 */ ER_SLAVE_SAME_ID,
        FlashbackNotSupported                                       = /* 4053 */ ER_FLASHBACK_NOT_SUPPORTED,
        ErrorLast                                                   = /* 4053 */ ER_ERROR_LAST,

        /* client errors */

        ClientUnknownError                                          = /* 2000 */ CR_UNKNOWN_ERROR,
        ClientSocketCreateError                                     = /* 2001 */ CR_SOCKET_CREATE_ERROR,
        ClientConnectionError                                       = /* 2002 */ CR_CONNECTION_ERROR,
        ClientConnHostError                                         = /* 2003 */ CR_CONN_HOST_ERROR,
        ClientIpsockError                                           = /* 2004 */ CR_IPSOCK_ERROR,
        ClientUnknownHost                                           = /* 2005 */ CR_UNKNOWN_HOST,
        ClientServerGoneError                                       = /* 2006 */ CR_SERVER_GONE_ERROR,
        ClientVersionError                                          = /* 2007 */ CR_VERSION_ERROR,
        ClientOutOfMemory                                           = /* 2008 */ CR_OUT_OF_MEMORY,
        ClientWrongHostInfo                                         = /* 2009 */ CR_WRONG_HOST_INFO,
        ClientLocalhostConnection                                   = /* 2010 */ CR_LOCALHOST_CONNECTION,
        ClientTcpConnection                                         = /* 2011 */ CR_TCP_CONNECTION,
        ClientServerHandshakeErr                                    = /* 2012 */ CR_SERVER_HANDSHAKE_ERR,
        ClientServerLost                                            = /* 2013 */ CR_SERVER_LOST,
        ClientCommandsOutOfSync                                     = /* 2014 */ CR_COMMANDS_OUT_OF_SYNC,
        ClientNamedpipeConnection                                   = /* 2015 */ CR_NAMEDPIPE_CONNECTION,
        ClientNamedpipewaitError                                    = /* 2016 */ CR_NAMEDPIPEWAIT_ERROR,
        ClientNamedpipeopenError                                    = /* 2017 */ CR_NAMEDPIPEOPEN_ERROR,
        ClientNamedpipesetstateError                                = /* 2018 */ CR_NAMEDPIPESETSTATE_ERROR,
        ClientCantReadCharset                                       = /* 2019 */ CR_CANT_READ_CHARSET,
        ClientNetPacketTooLarge                                     = /* 2020 */ CR_NET_PACKET_TOO_LARGE,
        ClientSslConnectionError                                    = /* 2026 */ CR_SSL_CONNECTION_ERROR,
        ClientMalformedPacket                                       = /* 2027 */ CR_MALFORMED_PACKET,
        ClientNoPrepareStmt                                         = /* 2030 */ CR_NO_PREPARE_STMT,
        ClientParamsNotBound                                        = /* 2031 */ CR_PARAMS_NOT_BOUND,
        ClientInvalidParameterNo                                    = /* 2034 */ CR_INVALID_PARAMETER_NO,
        ClientInvalidBufferUse                                      = /* 2035 */ CR_INVALID_BUFFER_USE,
        ClientUnsupportedParamType                                  = /* 2036 */ CR_UNSUPPORTED_PARAM_TYPE,
        ClientSharedMemoryConnection                                = /* 2037 */ CR_SHARED_MEMORY_CONNECTION,
        ClientSharedMemoryConnectError                              = /* 2038 */ CR_SHARED_MEMORY_CONNECT_ERROR,
        ClientConnUnknownProtocol                                   = /* 2047 */ CR_CONN_UNKNOWN_PROTOCOL,
        ClientSecureAuth                                            = /* 2049 */ CR_SECURE_AUTH,
        ClientNoData                                                = /* 2051 */ CR_NO_DATA,
        ClientNoStmtMetadata                                        = /* 2052 */ CR_NO_STMT_METADATA,
        ClientNotImplemented                                        = /* 2054 */ CR_NOT_IMPLEMENTED,
        ClientServerLostExtended                                    = /* 2055 */ CR_SERVER_LOST_EXTENDED,
        ClientStmtClosed                                            = /* 2056 */ CR_STMT_CLOSED,
        ClientNewStmtMetadata                                       = /* 2057 */ CR_NEW_STMT_METADATA,
        ClientAlreadyConnected                                      = /* 2058 */ CR_ALREADY_CONNECTED,
        ClientAuthPluginCannotLoad                                  = /* 2059 */ CR_AUTH_PLUGIN_CANNOT_LOAD,
        ClientDuplicateConnectionAttr                               = /* 2060 */ CR_DUPLICATE_CONNECTION_ATTR,
        ClientAuthPluginErr                                         = /* 2061 */ CR_AUTH_PLUGIN_ERR,
        ClientEventCreateFailed                                     = /* 5000 */ CR_EVENT_CREATE_FAILED,
        ClientBindAddrFailed                                        = /* 5001 */ CR_BIND_ADDR_FAILED,
        ClientAsyncNotSupported                                     = /* 5002 */ CR_ASYNC_NOT_SUPPORTED,
        ClientFunctionNotSupported                                  = /* 5003 */ CR_FUNCTION_NOT_SUPPORTED,
        ClientFileNotFound                                          = /* 5004 */ CR_FILE_NOT_FOUND,
        ClientFileRead                                              = /* 5005 */ CR_FILE_READ,
        ClientBulkWithoutParameters                                 = /* 5006 */ CR_BULK_WITHOUT_PARAMETERS,
    };

}
